@@ -12,8 +12,6 @@ from pathlib import Path
 from textwrap import wrap
 from typing import Any, Dict, List
 
-import napari.plugins._npe2 as _npe2
-
 
 class InfoAction(argparse.Action):
     def __call__(self, *args, **kwargs):
@@ -25,10 +23,9 @@ class InfoAction(argparse.Action):
         from .plugins import plugin_manager
 
         plugin_manager.discover_widgets()
-        errors = plugin_manager.get_errors()
-        if errors:
+        if errors := plugin_manager.get_errors():
             names = {e.plugin_name for e in errors}
-            print("\n‼️  Errors were detected in the following plugins:")
+            print("\n!!  Errors were detected in the following plugins:")
             print("(Run 'napari --plugin-info -v' for more details)")
             print("\n".join(f"  - {n}" for n in names))
         sys.exit()
@@ -43,9 +40,8 @@ class PluginInfoAction(argparse.Action):
         plugin_manager.discover_widgets()
         print(plugin_manager)
 
-        errors = plugin_manager.get_errors()
-        if errors:
-            print("‼️  Some errors occurred:")
+        if errors := plugin_manager.get_errors():
+            print("!!  Some errors occurred:")
             verbose = '-v' in sys.argv or '--verbose' in sys.argv
             if not verbose:
                 print("   (use '-v') to show full tracebacks")
@@ -95,7 +91,7 @@ def validate_unknown_args(unknown: List[str]) -> Dict[str, Any]:
 
     from napari.components.viewer_model import valid_add_kwargs
 
-    out: Dict[str, Any] = dict()
+    out: Dict[str, Any] = {}
     valid = set.union(*valid_add_kwargs().values())
     for i, arg in enumerate(unknown):
         if not arg.startswith("--"):
@@ -229,7 +225,7 @@ def parse_sys_argv():
 
 
 def _run():
-    from napari import run, view_path
+    from napari import Viewer, run
     from napari.settings import get_settings
 
     """Main program."""
@@ -284,7 +280,7 @@ def _run():
 
     else:
         if args.with_:
-            from .plugins import plugin_manager
+            from .plugins import _npe2, plugin_manager
 
             # if a plugin widget has been requested, this will fail immediately
             # if the requested plugin/widget is not available.
@@ -305,13 +301,14 @@ def _run():
         splash = NapariSplashScreen()
         splash.close()  # will close once event loop starts
 
-        # viewer is unused but _must_  be kept around.
+        # viewer _must_  be kept around.
         # it will be referenced by the global window only
         # once napari has finished starting
         # but in the meantime if the garbage collector runs;
         # it will collect it and hang napari at start time.
         # in a way that is machine, os, time (and likely weather dependant).
-        viewer = view_path(  # noqa: F841
+        viewer = Viewer()
+        viewer._window._qt_viewer._qt_open(
             args.paths,
             stack=args.stack,
             plugin=args.plugin,
@@ -441,7 +438,7 @@ def main():
             warnings.warn(msg)
 
     # Prevent https://github.com/napari/napari/issues/3415
-    if sys.platform == "darwin" and sys.version_info >= (3, 8):
+    if sys.platform == "darwin":
         import multiprocessing
 
         multiprocessing.set_start_method('fork')
