@@ -18,7 +18,6 @@ from ...layers.image._image_constants import (
 from ...utils.action_manager import action_manager
 from ...utils.translations import trans
 from .qt_image_controls_base import QtBaseImageControls
-from .qt_layer_controls_base import LayerListGridLayout
 
 
 class QtImageControls(QtBaseImageControls):
@@ -91,28 +90,34 @@ class QtImageControls(QtBaseImageControls):
         self.depictionComboBox.activated[str].connect(self.changeDepiction)
         self.depictionLabel = QLabel(trans._('depiction:'))
 
-        self.planeControls = QtPlaneControls()
-        self.planeControls.planeThicknessSlider.setValue(
-            self.layer.plane.thickness
-        )
-        self.planeControls.planeThicknessSlider.valueChanged.connect(
-            self.changePlaneThickness
-        )
+        # plane controls
+        self.planeNormalButtons = PlaneNormalButtons(self)
+        self.planeNormalLabel = QLabel(trans._('plane normal:'))
         action_manager.bind_button(
             'napari:orient_plane_normal_along_z',
-            self.planeControls.planeNormalButtons.zButton,
+            self.planeNormalButtons.zButton,
         )
         action_manager.bind_button(
             'napari:orient_plane_normal_along_y',
-            self.planeControls.planeNormalButtons.yButton,
+            self.planeNormalButtons.yButton,
         )
         action_manager.bind_button(
             'napari:orient_plane_normal_along_x',
-            self.planeControls.planeNormalButtons.xButton,
+            self.planeNormalButtons.xButton,
         )
         action_manager.bind_button(
             'napari:orient_plane_normal_along_view_direction',
-            self.planeControls.planeNormalButtons.obliqueButton,
+            self.planeNormalButtons.obliqueButton,
+        )
+
+        self.planeThicknessSlider = QLabeledDoubleSlider(Qt.Horizontal, self)
+        self.planeThicknessLabel = QLabel(trans._('plane thickness:'))
+        self.planeThicknessSlider.setFocusPolicy(Qt.NoFocus)
+        self.planeThicknessSlider.setMinimum(1)
+        self.planeThicknessSlider.setMaximum(50)
+        self.planeThicknessSlider.setValue(self.layer.plane.thickness)
+        self.planeThicknessSlider.valueChanged.connect(
+            self.changePlaneThickness
         )
 
         sld = QSlider(Qt.Horizontal, parent=self)
@@ -146,34 +151,23 @@ class QtImageControls(QtBaseImageControls):
             colormap_layout.addWidget(self.colormapComboBox)
         colormap_layout.addStretch(1)
 
-        # grid_layout created in QtLayerControls
-        # addWidget(widget, row, column, [row_span, column_span])
-        self.grid_layout.addWidget(QLabel(trans._('opacity:')), 0, 0)
-        self.grid_layout.addWidget(self.opacitySlider, 0, 1)
-        self.grid_layout.addWidget(QLabel(trans._('contrast limits:')), 1, 0)
-        self.grid_layout.addWidget(self.contrastLimitsSlider, 1, 1)
-        self.grid_layout.addWidget(QLabel(trans._('auto-contrast:')), 2, 0)
-        self.grid_layout.addWidget(self.autoScaleBar, 2, 1)
-        self.grid_layout.addWidget(QLabel(trans._('gamma:')), 3, 0)
-        self.grid_layout.addWidget(self.gammaSlider, 3, 1)
-        self.grid_layout.addWidget(QLabel(trans._('colormap:')), 4, 0)
-        self.grid_layout.addLayout(colormap_layout, 4, 1)
-        self.grid_layout.addWidget(QLabel(trans._('blending:')), 5, 0)
-        self.grid_layout.addWidget(self.blendComboBox, 5, 1)
-        self.grid_layout.addWidget(self.interpLabel, 6, 0)
-        self.grid_layout.addWidget(self.interpComboBox, 6, 1)
-        self.grid_layout.addWidget(self.renderLabel, 7, 0)
-        self.grid_layout.addWidget(self.renderComboBox, 7, 1)
-        self.grid_layout.addWidget(self.depictionLabel, 8, 0)
-        self.grid_layout.addWidget(self.depictionComboBox, 8, 1)
-        self.grid_layout.addWidget(self.planeControls, 9, 0, 2, 2)
-        self.grid_layout.addWidget(self.isoThresholdLabel, 11, 0)
-        self.grid_layout.addWidget(self.isoThresholdSlider, 11, 1)
-        self.grid_layout.addWidget(self.attenuationLabel, 12, 0)
-        self.grid_layout.addWidget(self.attenuationSlider, 12, 1)
-        self.grid_layout.setRowStretch(13, 1)
-        self.grid_layout.setColumnStretch(1, 1)
-        self.grid_layout.setSpacing(4)
+        self.layout().addRow(trans._('opacity:'), self.opacitySlider)
+        self.layout().addRow(
+            trans._('contrast limits:'), self.contrastLimitsSlider
+        )
+        self.layout().addRow(trans._('auto-contrast:'), self.autoScaleBar)
+        self.layout().addRow(trans._('gamma:'), self.gammaSlider)
+        self.layout().addRow(trans._('colormap:'), colormap_layout)
+        self.layout().addRow(trans._('blending:'), self.blendComboBox)
+        self.layout().addRow(self.interpLabel, self.interpComboBox)
+        self.layout().addRow(self.depictionLabel, self.depictionComboBox)
+        self.layout().addRow(self.renderLabel, self.renderComboBox)
+        self.layout().addRow(self.isoThresholdLabel, self.isoThresholdSlider)
+        self.layout().addRow(self.attenuationLabel, self.attenuationSlider)
+        self.layout().addRow(self.planeNormalLabel, self.planeNormalButtons)
+        self.layout().addRow(
+            self.planeThicknessLabel, self.planeThicknessSlider
+        )
 
     def changeInterpolation(self, text):
         """Change interpolation mode for image display.
@@ -291,9 +285,7 @@ class QtImageControls(QtBaseImageControls):
 
     def _on_plane_thickness_change(self):
         with self.layer.plane.events.blocker():
-            self.planeControls.planeThicknessSlider.setValue(
-                self.layer.plane.thickness
-            )
+            self.planeThicknessSlider.setValue(self.layer.plane.thickness)
 
     def _toggle_rendering_parameter_visbility(self):
         """Hide isosurface rendering parameters if they aren't needed."""
@@ -315,9 +307,15 @@ class QtImageControls(QtBaseImageControls):
         """Hide plane rendering controls if they aren't needed."""
         depiction = VolumeDepiction(self.layer.depiction)
         if depiction == VolumeDepiction.VOLUME or self.layer._ndisplay == 2:
-            self.planeControls.hide()
+            self.planeNormalButtons.hide()
+            self.planeNormalLabel.hide()
+            self.planeThicknessSlider.hide()
+            self.planeThicknessLabel.hide()
         if depiction == VolumeDepiction.PLANE and self.layer._ndisplay == 3:
-            self.planeControls.show()
+            self.planeNormalButtons.show()
+            self.planeNormalLabel.show()
+            self.planeThicknessSlider.show()
+            self.planeThicknessLabel.show()
 
     def _update_interpolation_combo(self):
         self.interpComboBox.clear()
@@ -383,26 +381,3 @@ class PlaneNormalButtons(QWidget):
         self.layout().addWidget(self.yButton)
         self.layout().addWidget(self.zButton)
         self.layout().addWidget(self.obliqueButton)
-
-
-class QtPlaneControls(QWidget):
-    """Qt widget encapsulating plane controls for an image layer."""
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.grid_layout = LayerListGridLayout(self)
-        self.setLayout(self.grid_layout)
-
-        self.planeNormalLabel = QLabel(trans._('plane normal:'))
-        self.planeNormalButtons = PlaneNormalButtons(parent=self)
-
-        self.planeThicknessSlider = QLabeledDoubleSlider(Qt.Horizontal, self)
-        self.planeThicknessSlider.setFocusPolicy(Qt.NoFocus)
-        self.planeThicknessSlider.setMinimum(1)
-        self.planeThicknessSlider.setMaximum(50)
-        self.planeThicknessLabel = QLabel(trans._('plane thickness:'))
-
-        self.grid_layout.addWidget(self.planeNormalLabel, 1, 0)
-        self.grid_layout.addWidget(self.planeNormalButtons, 1, 1)
-        self.grid_layout.addWidget(self.planeThicknessLabel, 2, 0)
-        self.grid_layout.addWidget(self.planeThicknessSlider, 2, 1)
