@@ -2,7 +2,7 @@ from collections.abc import Iterable
 
 import numpy as np
 from qtpy.QtCore import Qt
-from qtpy.QtWidgets import QButtonGroup, QCheckBox, QGridLayout, QLabel
+from qtpy.QtWidgets import QButtonGroup, QCheckBox, QGridLayout
 
 from ...layers.shapes._shapes_constants import Mode
 from ...utils.action_manager import action_manager
@@ -287,24 +287,13 @@ class QtShapesControls(QtLayerControls):
         text_disp_cb.stateChanged.connect(self.change_text_visibility)
         self.textDispCheckBox = text_disp_cb
 
-        # grid_layout created in QtLayerControls
-        # addWidget(widget, row, column, [row_span, column_span])
-        self.grid_layout.addLayout(button_grid, 0, 0, 1, 2)
-        self.grid_layout.addWidget(QLabel(trans._('opacity:')), 1, 0)
-        self.grid_layout.addWidget(self.opacitySlider, 1, 1)
-        self.grid_layout.addWidget(QLabel(trans._('edge width:')), 2, 0)
-        self.grid_layout.addWidget(self.widthSlider, 2, 1)
-        self.grid_layout.addWidget(QLabel(trans._('blending:')), 3, 0)
-        self.grid_layout.addWidget(self.blendComboBox, 3, 1)
-        self.grid_layout.addWidget(QLabel(trans._('face color:')), 4, 0)
-        self.grid_layout.addWidget(self.faceColorEdit, 4, 1)
-        self.grid_layout.addWidget(QLabel(trans._('edge color:')), 5, 0)
-        self.grid_layout.addWidget(self.edgeColorEdit, 5, 1)
-        self.grid_layout.addWidget(QLabel(trans._('display text:')), 6, 0)
-        self.grid_layout.addWidget(self.textDispCheckBox, 6, 1)
-        self.grid_layout.setRowStretch(7, 1)
-        self.grid_layout.setColumnStretch(1, 1)
-        self.grid_layout.setSpacing(4)
+        self.layout().addRow(button_grid)
+        self.layout().addRow(trans._('opacity:'), self.opacitySlider)
+        self.layout().addRow(trans._('edge width:'), self.widthSlider)
+        self.layout().addRow(trans._('blending:'), self.blendComboBox)
+        self.layout().addRow(trans._('face color:'), self.faceColorEdit)
+        self.layout().addRow(trans._('edge color:'), self.edgeColorEdit)
+        self.layout().addRow(trans._('display text:'), self.textDispCheckBox)
 
     def _on_mode_change(self, event):
         """Update ticks in checkbox widgets when shapes layer mode changed.
