@@ -15,6 +15,7 @@ from qtpy.QtWidgets import (
 
 from ...utils.action_manager import action_manager
 from ...utils.interactions import Shortcut
+from ...utils.misc import in_ipython
 from ...utils.translations import trans
 from ..dialogs.qt_modal import QtPopup
 from .qt_dims_sorter import QtDimsSorter
@@ -120,6 +121,8 @@ class QtViewerButtons(QFrame):
             'console', action='napari:toggle_console_visibility'
         )
         self.consoleButton.setProperty('expanded', False)
+        if in_ipython():
+            self.consoleButton.setEnabled(False)
 
         rdb = QtViewerPushButton('roll', action='napari:roll_axes')
         self.rollDimsButton = rdb
