@@ -11,22 +11,27 @@ from napari.utils.notifications import notification_manager
 
 # not testing these examples
 skip = [
-    'surface_timeseries.py',  # needs nilearn
-    '3d_kymograph.py',  # needs tqdm
-    'live_tiffs.py',  # requires files
-    'tiled-rendering-2d.py',  # too slow
-    'live_tiffs_generator.py',
+    'surface_timeseries_.py',  # needs nilearn
+    '3d_kymograph_.py',  # needs tqdm
+    'live_tiffs_.py',  # requires files
+    'tiled-rendering-2d_.py',  # too slow
+    'live_tiffs_generator_.py',
     'points-over-time.py',  # too resource hungry
-    'embed_ipython.py',  # fails without monkeypatch
+    'embed_ipython_.py',  # fails without monkeypatch
     'custom_key_bindings.py',  # breaks EXPECTED_NUMBER_OF_VIEWER_METHODS later
     'new_theme.py',  # testing theme is extremely slow on CI
     'dynamic-projections-dask.py',  # extremely slow / does not finish
+    'spheres_.py',  # needs meshzoo
+    'clipping_planes_interactive_.py',  # needs meshzoo
 ]
 
-
-if os.environ.get('MIN_REQ', '') == '1':
+try:
+    import meshzoo
+except ModuleNotFoundError:
+    # this should be restored once numpy min req is
     skip.extend(['spheres.py', 'clipping_planes_interactive.py'])
 
+
 EXAMPLE_DIR = Path(napari.__file__).parent.parent / 'examples'
 # using f.name here and re-joining at `run_path()` for test key presentation
 # (works even if the examples list is empty, as opposed to using an ids lambda)
