@@ -14,7 +14,7 @@ class VispyVectorsLayer(VispyBaseLayer):
         self.reset()
         self._on_data_change()
 
-    def _on_data_change(self, event=None):
+    def _on_data_change(self):
         if (
             len(self.layer._view_vertices) == 0
             or len(self.layer._view_faces) == 0
