@@ -35,7 +35,14 @@ def _opengl_context():
             canvas.close()
 
 
-@lru_cache()
+@lru_cache(maxsize=1)
+def get_gl_extensions() -> str:
+    """Get basic info about the Gl capabilities of this machine"""
+    with _opengl_context():
+        return gl.glGetParameter(gl.GL_EXTENSIONS)
+
+
+@lru_cache
 def get_max_texture_sizes() -> Tuple[int, int]:
     """Return the maximum texture sizes for 2D and 3D rendering.
 
