@@ -6,6 +6,8 @@ import pytest
 from napari.components import LayerList
 from napari.layers import Image
 
+BUILTINS = 'napari'
+
 
 def test_empty_layers_list():
     """
@@ -327,6 +329,7 @@ def test_toggle_visibility():
 
 
 # the layer_data_and_types fixture is defined in napari/conftest.py
+@pytest.mark.filterwarnings('ignore:distutils Version classes are deprecated')
 def test_layers_save(tmpdir, layer_data_and_types):
     """Test saving all layer data."""
     list_of_layers, _, _, filenames = layer_data_and_types
@@ -338,7 +341,7 @@ def test_layers_save(tmpdir, layer_data_and_types):
     assert not os.path.isdir(path)
 
     # Write data
-    layers.save(path, plugin='builtins')
+    layers.save(path, plugin=BUILTINS)
 
     # Check folder now exists
     assert os.path.isdir(path)
@@ -366,7 +369,7 @@ def test_layers_save_none_selected(tmpdir, layer_data_and_types):
 
     # Write data (will get a warning that nothing is selected)
     with pytest.warns(UserWarning):
-        layers.save(path, selected=True, plugin='builtins')
+        layers.save(path, selected=True, plugin=BUILTINS)
 
     # Check folder still does not exist
     assert not os.path.isdir(path)
@@ -393,7 +396,7 @@ def test_layers_save_selected(tmpdir, layer_data_and_types):
     assert not os.path.isdir(path)
 
     # Write data
-    layers.save(path, selected=True, plugin='builtins')
+    layers.save(path, selected=True, plugin=BUILTINS)
 
     # Check folder exists
     assert os.path.isdir(path)
@@ -410,7 +413,8 @@ def test_layers_save_selected(tmpdir, layer_data_and_types):
 
 
 # the layers fixture is defined in napari/conftest.py
-def test_layers_save_svg(tmpdir, layers):
+@pytest.mark.filterwarnings('ignore:`np.int` is a deprecated alias for')
+def test_layers_save_svg(tmpdir, layers, napari_svg_name):
     """Test saving all layer data to an svg."""
     path = os.path.join(tmpdir, 'layers_file.svg')
 
@@ -418,7 +422,7 @@ def test_layers_save_svg(tmpdir, layers):
     assert not os.path.isfile(path)
 
     # Write data
-    layers.save(path, plugin='svg')
+    layers.save(path, plugin=napari_svg_name)
 
     # Check file now exists
     assert os.path.isfile(path)
