@@ -28,8 +28,8 @@ class LayerList(SelectableEventedList[Layer]):
     data : iterable
         Iterable of napari.layer.Layer
 
-    Attributes
-    ----------
+    Events
+    ------
     inserting : (index: int)
         emitted before an item is inserted at ``index``
     inserted : (index: int, value: T)
@@ -49,7 +49,7 @@ class LayerList(SelectableEventedList[Layer]):
     reordered : (value: self)
         emitted when the list is reordered (eg. moved/reversed).
     selection.changed : (added: Set[_T], removed: Set[_T])
-        Emitted when the set changes, includes item(s) that have been added
+        emitted when the set changes, includes item(s) that have been added
         and/or removed from the set.
     selection.active : (value: _T)
         emitted when the current item has changed.
