@@ -22,10 +22,16 @@ import numpy as np
 from pydantic import Extra, Field, validator
 
 from .. import layers
+from ..errors import (
+    MultipleReaderError,
+    NoAvailableReaderError,
+    ReaderPluginError,
+)
 from ..layers import Image, Layer
 from ..layers._source import layer_source
 from ..layers.image._image_utils import guess_labels
 from ..layers.utils.stack_utils import split_channels
+from ..plugins.utils import get_potential_readers, get_preferred_reader
 from ..settings import get_settings
 from ..utils._register import create_func as create_add_method
 from ..utils.colormaps import ensure_colormap
@@ -293,10 +299,11 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
 
     def _new_labels(self):
         """Create new labels layer filling full world coordinates space."""
-        extent = self.layers.extent.world
-        scale = self.layers.extent.step
+        layers_extent = self.layers.extent
+        extent = layers_extent.world
+        scale = layers_extent.step
         scene_size = extent[1] - extent[0]
-        corner = extent[0] + 0.5 * self.layers.extent.step
+        corner = extent[0] + 0.5 * layers_extent.step
         shape = [
             np.round(s / sc).astype('int') if s > 0 else 1
             for s, sc in zip(scene_size, scale)
@@ -523,6 +530,7 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
         gamma=1,
         interpolation='nearest',
         rendering='mip',
+        depiction='volume',
         iso_threshold=0.5,
         attenuation=0.05,
         name=None,
@@ -537,7 +545,7 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
         visible=True,
         multiscale=None,
         cache=True,
-        experimental_slicing_plane=None,
+        plane=None,
         experimental_clipping_planes=None,
     ) -> Union[Image, List[Image]]:
         """Add an image layer to the layer list.
@@ -590,6 +598,11 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
             Rendering mode used by vispy. Must be one of our supported
             modes. If a list then must be same length as the axis that is being
             expanded as channels.
+        depiction : str
+            Selects a preset volume depiction mode in vispy
+
+            * volume: images are rendered as 3D volumes.
+            * plane: images are rendered as 2D planes embedded in 3D.
         iso_threshold : float or list
             Threshold for isosurface. If a list then must be same length as the
             axis that is being expanded as channels.
@@ -651,7 +664,7 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
         cache : bool
             Whether slices of out-of-core datasets should be cached upon
             retrieval. Currently, this only applies to dask arrays.
-        experimental_slicing_plane : dict or SlicingPlane
+        plane : dict or SlicingPlane
             Properties defining plane rendering in 3D. Properties are defined in
             data coordinates. Valid dictionary keys are
             {'position', 'normal', 'thickness', and 'enabled'}.
@@ -684,6 +697,7 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
             'gamma': gamma,
             'interpolation': interpolation,
             'rendering': rendering,
+            'depiction': depiction,
             'iso_threshold': iso_threshold,
             'attenuation': attenuation,
             'name': name,
@@ -698,7 +712,7 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
             'visible': visible,
             'multiscale': multiscale,
             'cache': cache,
-            'experimental_slicing_plane': experimental_slicing_plane,
+            'plane': plane,
             'experimental_clipping_planes': experimental_clipping_planes,
         }
 
@@ -716,7 +730,7 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
 
         if channel_axis is None:
             kwargs['colormap'] = kwargs['colormap'] or 'gray'
-            kwargs['blending'] = kwargs['blending'] or 'translucent'
+            kwargs['blending'] = kwargs['blending'] or 'translucent_no_depth'
             # Helpful message if someone tries to add mulit-channel kwargs,
             # but forget the channel_axis arg
             for k, v in kwargs.items():
@@ -840,7 +854,7 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
         path: PathOrPaths,
         *,
         stack: bool = False,
-        plugin: Optional[str] = None,
+        plugin: Optional[str] = 'builtins',
         layer_type: Optional[str] = None,
         **kwargs,
     ) -> List[Layer]:
@@ -861,9 +875,11 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
             ``False``, then the ``path`` list is broken up and passed to plugin
             readers one by one.  by default False.
         plugin : str, optional
-            Name of a plugin to use.  If provided, will force ``path`` to be
-            read with the specified ``plugin``.  If the requested plugin cannot
-            read ``path``, an exception will be raised.
+            Name of a plugin to use, by default builtins.  If provided, will
+            force ``path`` to be read with the specified ``plugin``.
+            If None, ``plugin`` will be read from preferences or inferred if just
+            one reader is compatible.
+            If the requested plugin cannot read ``path``, an exception will be raised.
         layer_type : str, optional
             If provided, will force data read from ``path`` to be passed to the
             corresponding ``add_<layer_type>`` method (along with any
@@ -879,20 +895,27 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
         layers : list
             A list of any layers that were added to the viewer.
         """
-        paths = [path] if isinstance(path, (Path, str)) else path
-        paths = [os.fspath(path) for path in paths]  # PathObjects -> str
-        if not isinstance(paths, (tuple, list)):
-            raise ValueError(
-                trans._(
-                    "'path' argument must be a string, list, or tuple",
-                    deferred=True,
-                )
-            )
+
+        paths: List[str | Path] = (
+            [os.fspath(path)]
+            if isinstance(path, (Path, str))
+            else [os.fspath(p) for p in path]
+        )
 
         if stack:
-            return self._add_layers_with_plugins(
-                paths, kwargs, plugin=plugin, layer_type=layer_type
-            )
+            if plugin:
+                layers = self._add_layers_with_plugins(
+                    paths,
+                    kwargs=kwargs,
+                    plugin=plugin,
+                    layer_type=layer_type,
+                    stack=stack,
+                )
+            else:
+                layers = self._open_or_raise_error(
+                    paths, kwargs, layer_type, stack
+                )
+            return layers
 
         added: List[Layer] = []  # for layers that get added
         with progress(
@@ -903,16 +926,159 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
             else None,  # indeterminate bar for 1 file
         ) as pbr:
             for _path in pbr:
-                added.extend(
-                    self._add_layers_with_plugins(
-                        _path, kwargs, plugin=plugin, layer_type=layer_type
+                if plugin:
+                    added.extend(
+                        self._add_layers_with_plugins(
+                            [_path],
+                            kwargs=kwargs,
+                            plugin=plugin,
+                            layer_type=layer_type,
+                            stack=stack,
+                        )
+                    )
+                # no plugin choice was made
+                else:
+                    layers = self._open_or_raise_error(
+                        [_path], kwargs, layer_type, stack
+                    )
+                    added.extend(layers)
+
+        return added
+
+    def _open_or_raise_error(
+        self,
+        paths: List[Union[Path, str]],
+        kwargs: Dict[str, Any] = {},
+        layer_type: Optional[str] = None,
+        stack: bool = False,
+    ):
+        """Open paths if plugin choice is unambiguous, raising any errors.
+
+        This function will open paths if there is no plugin choice to be made
+        i.e. there is a preferred reader associated with this file extension,
+        or there is only one plugin available. Any errors that occur during
+        the opening process are raised. If multiple plugins
+        are available to read these paths, an error is raised specifying
+        this.
+
+        Errors are also raised by this function when the given paths are not
+        a list or tuple, or if no plugins are available to read the files.
+        This assumes all files have the same extension, as other cases
+        are not yet supported.
+
+        This function is called from ViewerModel.open, which raises any
+        errors returned. The QtViewer also calls this method but catches
+        exceptions and opens a dialog for users to make a plugin choice.
+
+        Parameters
+        ----------
+        paths : List[Path | str]
+            list of file paths to open
+        kwargs : Dict[str, Any], optional
+            keyword arguments to pass to layer adding method, by default {}
+        layer_type : Optional[str], optional
+            layer type for paths, by default None
+        stack : bool, optional
+            True if files should be opened as a stack, by default False
+
+        Returns
+        -------
+        added
+            list of layers added
+        plugin
+            plugin used to try opening paths, if any
+
+        Raises
+        ------
+        TypeError
+            when paths is *not* a list or tuple
+        NoAvailableReaderError
+            when no plugins are available to read path
+        ReaderPluginError
+            when reading with only available or prefered plugin fails
+        MultipleReaderError
+            when multiple readers are available to read the path
+        """
+        paths = [os.fspath(path) for path in paths]  # PathObjects -> str
+
+        added = []
+        plugin = None
+        _path = paths[0]
+        # we want to display the paths nicely so make a help string here
+        path_message = f"[{_path}], ...]" if len(paths) > 1 else _path
+
+        readers = get_potential_readers(_path)
+        if not readers:
+            raise NoAvailableReaderError(
+                trans._(
+                    'No plugin found capable of reading {path_message}.',
+                    path_message=path_message,
+                    deferred=True,
+                ),
+                paths,
+            )
+
+        plugin = get_preferred_reader(_path)
+        if plugin and plugin not in readers:
+            warnings.warn(
+                RuntimeWarning(
+                    trans._(
+                        f"Can't find {plugin} plugin associated with {path_message} files. ",
+                        plugin=plugin,
+                        path_message=path_message,
+                    )
+                    + trans._(
+                        "This may be because you've switched environments, or have uninstalled the plugin without updating the reader preference. "
+                    )
+                    + trans._(
+                        "You can remove this preference in the preference dialog, or by editing `settings.plugins.extension2reader`."
                     )
                 )
+            )
+            plugin = None
+
+        # preferred plugin exists, or we just have one plugin available
+        if plugin or len(readers) == 1:
+            plugin = plugin or next(iter(readers.keys()))
+            try:
+                added = self._add_layers_with_plugins(
+                    paths,
+                    kwargs=kwargs,
+                    stack=stack,
+                    plugin=plugin,
+                    layer_type=layer_type,
+                )
+            # plugin failed
+            except Exception as e:
+                raise ReaderPluginError(
+                    trans._(
+                        'Tried opening with {plugin}, but failed.',
+                        deferred=True,
+                        plugin=plugin,
+                    ),
+                    plugin,
+                    paths,
+                ) from e
+        # multiple plugins
+        else:
+            raise MultipleReaderError(
+                trans._(
+                    "Multiple plugins found capable of reading {path_message}. Select plugin from {plugins} and pass to reading function e.g. `viewer.open(..., plugin=...)`.",
+                    path_message=path_message,
+                    plugins=readers,
+                    deferred=True,
+                ),
+                list(readers.keys()),
+                paths,
+            )
+
         return added
 
     def _add_layers_with_plugins(
         self,
-        path_or_paths: Union[str, Sequence[str]],
+        paths: List[str],
+        *,
+        stack: bool,
         kwargs: Optional[dict] = None,
         plugin: Optional[str] = None,
         layer_type: Optional[str] = None,
@@ -925,7 +1091,7 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
 
         Parameters
         ----------
-        path_or_paths : str or list of str
+        paths : list of str
             A filepath, directory, or URL (or a list of any) to open. If a
             list, the assumption is that the list is to be treated as a stack.
         kwargs : dict, optional
@@ -941,6 +1107,10 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
             additional) ``kwargs`` provided to this function.  This *may*
             result in exceptions if the data returned from the path is not
             compatible with the layer_type.
+        stack : bool
+            See `open` method
+            Stack=False => path is unique string, and list of len(1)
+            Stack=True => path is list of path
 
         Returns
         -------
@@ -949,23 +1119,33 @@ class ViewerModel(KeymapProvider, MousemapProvider, EventedModel):
         """
         from ..plugins.io import read_data_with_plugins
 
-        layer_data, hookimpl = read_data_with_plugins(
-            path_or_paths, plugin=plugin
-        )
+        assert stack is not None
+        assert isinstance(paths, list)
+        assert not isinstance(paths, str)
+        for p in paths:
+            assert isinstance(p, str)
+
+        if stack:
+            layer_data, hookimpl = read_data_with_plugins(
+                paths, plugin=plugin, stack=stack
+            )
+        else:
+            assert len(paths) == 1
+            layer_data, hookimpl = read_data_with_plugins(
+                paths, plugin=plugin, stack=stack
+            )
 
         # glean layer names from filename. These will be used as *fallback*
         # names, if the plugin does not return a name kwarg in their meta dict.
         filenames = []
-        if isinstance(path_or_paths, str):
-            filenames = itertools.repeat(path_or_paths)
-        elif is_sequence(path_or_paths):
-            if len(path_or_paths) == len(layer_data):
-                filenames = iter(path_or_paths)
-            else:
-                # if a list of paths has been returned as a list of layer data
-                # without a 1:1 relationship between the two lists we iterate
-                # over the first name
-                filenames = itertools.repeat(path_or_paths[0])
+
+        if len(paths) == len(layer_data):
+            filenames = iter(paths)
+        else:
+            # if a list of paths has been returned as a list of layer data
+            # without a 1:1 relationship between the two lists we iterate
+            # over the first name
+            filenames = itertools.repeat(paths[0])
 
         # add each layer to the viewer
         added: List[Layer] = []  # for layers that get added
