@@ -1,11 +1,12 @@
 """ImageSlice class.
 """
+from __future__ import annotations
+
 import logging
-from typing import Callable
+from typing import TYPE_CHECKING, Callable
 
 import numpy as np
 
-from ...types import ArrayLike
 from ...utils import config
 from ._image_loader import ImageLoader
 from ._image_slice_data import ImageSliceData
@@ -13,6 +14,9 @@ from ._image_view import ImageView
 
 LOGGER = logging.getLogger("napari.loader")
 
+if TYPE_CHECKING:
+    from ...types import ArrayLike
+
 
 def _create_loader_class() -> ImageLoader:
     """Return correct ImageLoader for sync or async.
