@@ -736,7 +736,7 @@ def test_image_state_update():
         setattr(image, k, v)
 
 
-def test_instiantiate_with_experimental_slicing_plane_dict():
+def test_instantiate_with_plane_parameter_dict():
     """Test that an image layer can be instantiated with plane parameters
     in a dictionary.
     """
@@ -745,23 +745,21 @@ def test_instiantiate_with_experimental_slicing_plane_dict():
         'normal': (1, 1, 1),
         'thickness': 22,
     }
-    image = Image(
-        np.ones((32, 32, 32)), experimental_slicing_plane=plane_parameters
-    )
+    image = Image(np.ones((32, 32, 32)), plane=plane_parameters)
     for k, v in plane_parameters.items():
         if k == 'normal':
             v = tuple(v / np.linalg.norm(v))
-        assert v == getattr(image.experimental_slicing_plane, k, v)
+        assert v == getattr(image.plane, k, v)
 
 
-def test_instiantiate_with_experimental_slicing_plane():
+def test_instiantiate_with_plane():
     """Test that an image layer can be instantiated with plane parameters
     in a Plane.
     """
     plane = SlicingPlane(position=(32, 32, 32), normal=(1, 1, 1), thickness=22)
-    image = Image(np.ones((32, 32, 32)), experimental_slicing_plane=plane)
+    image = Image(np.ones((32, 32, 32)), plane=plane)
     for k, v in plane.dict().items():
-        assert v == getattr(image.experimental_slicing_plane, k, v)
+        assert v == getattr(image.plane, k, v)
 
 
 def test_instantiate_with_clipping_planelist():
