@@ -55,12 +55,15 @@ class IntensityVisualizationMixin:
         """napari.utils.Colormap: colormap for luminance images."""
         return self._colormap
 
-    @colormap.setter
-    def colormap(self, colormap):
+    def _set_colormap(self, colormap):
         self._colormap = ensure_colormap(colormap)
         self._update_thumbnail()
         self.events.colormap()
 
+    @colormap.setter
+    def colormap(self, colormap):
+        self._set_colormap(colormap)
+
     @property
     def colormaps(self):
         """tuple of str: names of available colormaps."""
