@@ -71,8 +71,10 @@ class Points(Layer):
         Size of the point marker in data pixels. If given as a scalar, all points are made
         the same size. If given as an array, size must be the same or broadcastable
         to the same shape as the data.
-    edge_width : float
+    edge_width : float, array
         Width of the symbol edge in pixels.
+    edge_width_is_relative : bool
+        If enabled, edge_width is interpreted as a fraction of the point size.
     edge_color : str, array-like, dict
         Color of the point marker border. Numeric color values should be RGB(A).
     edge_color_cycle : np.ndarray, list
@@ -139,10 +141,11 @@ class Points(Layer):
         Currently, this only applies to dask arrays.
     shading : str, Shading
         Render lighting and shading on points. Options are:
-            * 'none'
-                No shading is added to the points.
-            * 'spherical'
-                Shading and depth buffer are changed to give a 3D spherical look to the points
+
+        * 'none'
+          No shading is added to the points.
+        * 'spherical'
+          Shading and depth buffer are changed to give a 3D spherical look to the points
     experimental_canvas_size_limits : tuple of float
         Lower and upper limits for the size of points in canvas pixels.
     shown : 1-D array of bool
@@ -170,8 +173,10 @@ class Points(Layer):
     size : array (N, D)
         Array of sizes for each point in each dimension. Must have the same
         shape as the layer `data`.
-    edge_width : float
+    edge_width : array (N,)
         Width of the marker edges in pixels for all points
+    edge_width : array (N,)
+        Width of the marker edges for all points as a fraction of their size.
     edge_color : Nx4 numpy array
         Array of edge color RGBA values, one for each point.
     edge_color_cycle : np.ndarray, list
@@ -199,11 +204,14 @@ class Points(Layer):
     current_size : float
         Size of the marker for the next point to be added or the currently
         selected point.
+    current_edge_width : float
+        Edge width of the marker for the next point to be added or the currently
+        selected point.
     current_edge_color : str
-        Size of the marker edge for the next point to be added or the currently
+        Edge color of the marker edge for the next point to be added or the currently
         selected point.
     current_face_color : str
-        Size of the marker edge for the next point to be added or the currently
+        Face color of the marker edge for the next point to be added or the currently
         selected point.
     out_of_slice_display : bool
         If True, renders points not just in central plane but also slightly out of slice
@@ -248,6 +256,8 @@ class Points(Layer):
         2D coordinates of points in the currently viewed slice.
     _view_size : array (M, )
         Size of the point markers in the currently viewed slice.
+    _view_edge_width : array (M, )
+        Edge width of the point markers in the currently viewed slice.
     _indices_view : array (M, )
         Integer indices of the points in the currently viewed slice and are shown.
     _selected_view :
@@ -280,7 +290,8 @@ class Points(Layer):
         text=None,
         symbol='o',
         size=10,
-        edge_width=1,
+        edge_width=0.1,
+        edge_width_is_relative=True,
         edge_color='black',
         edge_color_cycle=None,
         edge_colormap='viridis',
@@ -334,6 +345,7 @@ class Points(Layer):
             mode=Event,
             size=Event,
             edge_width=Event,
+            edge_width_is_relative=Event,
             face_color=Event,
             current_face_color=Event,
             edge_color=Event,
@@ -343,17 +355,12 @@ class Points(Layer):
             symbol=Event,
             out_of_slice_display=Event,
             n_dimensional=Event,
-            # n_dimensional=WarningEmitter(
-            # trans._(
-            # "'n_dimensional' is deprecated and will be removed in napari v0.5.0, "
-            # "use 'out_of_slice_display' instead."
-            # ),
-            # type='n_dimensional',
-            # ),
             highlight=Event,
             shading=Event,
             _antialias=Event,
             experimental_canvas_size_limits=Event,
+            features=Event,
+            feature_defaults=Event,
         )
 
         self._colors = get_color_namelist()
@@ -370,19 +377,20 @@ class Points(Layer):
 
         self._text = TextManager._from_layer(
             text=text,
-            n_text=len(self.data),
-            properties=self.properties,
+            features=self.features,
         )
 
-        # Save the point style params
-        self.symbol = symbol
-        self.edge_width = edge_width
+        self._edge_width_is_relative = False
+        self._shown = np.empty(0).astype(bool)
 
         # The following point properties are for the new points that will
         # be added. For any given property, if a list is passed to the
         # constructor so each point gets its own value then the default
         # value is used when adding new points
         self._current_size = np.asarray(size) if np.isscalar(size) else 10
+        self._current_edge_width = (
+            np.asarray(edge_width) if np.isscalar(edge_width) else 0.1
+        )
         # Indices of selected points
         self._selected_data = set()
         self._selected_data_stored = set()
@@ -436,9 +444,13 @@ class Points(Layer):
         else:
             self._out_of_slice_display = out_of_slice_display
 
-        self._shown = np.empty(0).astype(bool)
+        # Save the point style params
         self.size = size
         self.shown = shown
+        self.symbol = symbol
+        self.edge_width = edge_width
+        self.edge_width_is_relative = edge_width_is_relative
+
         self.experimental_canvas_size_limits = experimental_canvas_size_limits
         self.shading = shading
         self._antialias = True
@@ -462,6 +474,7 @@ class Points(Layer):
             with self._edge.events.blocker_all():
                 with self._face.events.blocker_all():
                     self._feature_table.resize(len(data))
+                    self.text.apply(self.features)
                     if len(data) < cur_npoints:
                         # If there are now fewer points, remove the size and colors of the
                         # extra ones
@@ -475,6 +488,7 @@ class Points(Layer):
                             )
                         self._shown = self._shown[: len(data)]
                         self._size = self._size[: len(data)]
+                        self._edge_width = self._edge_width[: len(data)]
 
                     elif len(data) > cur_npoints:
                         # If there are now more points, add the size and colors of the
@@ -491,6 +505,14 @@ class Points(Layer):
                             )
                         size = np.repeat([new_size], adding, axis=0)
 
+                        if len(self._edge_width) > 0:
+                            new_edge_width = copy(self._edge_width[-1])
+                        else:
+                            new_edge_width = self.current_edge_width
+                        edge_width = np.repeat(
+                            [new_edge_width], adding, axis=0
+                        )
+
                         # add new colors
                         self._edge._add(n_colors=adding)
                         self._face._add(n_colors=adding)
@@ -501,12 +523,13 @@ class Points(Layer):
                         )
 
                         self.size = np.concatenate((self._size, size), axis=0)
+                        self.edge_width = np.concatenate(
+                            (self._edge_width, edge_width), axis=0
+                        )
                         self.selected_data = set(
                             np.arange(cur_npoints, len(data))
                         )
 
-                        self.text.add(self.current_properties, adding)
-
         self._update_dims()
         self.events.data(value=self.data)
         self._set_editable()
@@ -549,9 +572,9 @@ class Points(Layer):
         self._update_color_manager(
             self._edge, self._feature_table, "edge_color"
         )
-        if self.text.values is not None:
-            self.refresh_text()
+        self.text.refresh(self.features)
         self.events.properties()
+        self.events.features()
 
     @property
     def feature_defaults(self):
@@ -619,6 +642,10 @@ class Points(Layer):
         self._edge._update_current_properties(current_properties)
         self._face._update_current_properties(current_properties)
         self.events.current_properties()
+        self.events.feature_defaults()
+        if update_indices is not None:
+            self.events.properties()
+            self.events.features()
 
     @property
     def text(self) -> TextManager:
@@ -629,16 +656,15 @@ class Points(Layer):
     def text(self, text):
         self._text._update_from_layer(
             text=text,
-            n_text=len(self.data),
-            properties=self.properties,
+            features=self.features,
         )
 
     def refresh_text(self):
         """Refresh the text values.
 
-        This is generally used if the properties were updated without changing the data
+        This is generally used if the features were updated without changing the data
         """
-        self.text.refresh_text(self.properties)
+        self.text.refresh(self.features)
 
     def _get_ndim(self) -> int:
         """Determine number of dimensions of the layer."""
@@ -677,26 +703,10 @@ class Points(Layer):
         """
         This property will soon be deprecated in favor of `out_of_slice_display`. Use that instead.
         """
-        # warnings.warn(
-        # trans._(
-        # "'n_dimensional' is deprecated and will be removed in napari v0.5.0, "
-        # "use 'out_of_slice_display' instead."
-        # ),
-        # DeprecationWarning,
-        # stacklevel=2,
-        # )
         return self._out_of_slice_display
 
     @n_dimensional.setter
     def n_dimensional(self, value: bool) -> None:
-        # warnings.warn(
-        # trans._(
-        # "'n_dimensional' is deprecated and will be removed in napari v0.5.0, "
-        # "use 'out_of_slice_display' instead."
-        # ),
-        # DeprecationWarning,
-        # stacklevel=2,
-        # )
         self.out_of_slice_display = value
 
     @property
@@ -717,7 +727,7 @@ class Points(Layer):
         self.events.highlight()
 
     @property
-    def size(self) -> Union[int, float, np.ndarray, list]:
+    def size(self) -> np.ndarray:
         """(N, D) array: size of all N points in D dimensions."""
         return self._size
 
@@ -804,14 +814,63 @@ class Points(Layer):
         self.refresh()
 
     @property
-    def edge_width(self) -> Union[None, int, float]:
-        """float: width used for all point markers."""
+    def edge_width(self) -> np.ndarray:
+        """(N, D) array: edge_width of all N points."""
         return self._edge_width
 
     @edge_width.setter
-    def edge_width(self, edge_width: Union[None, float]) -> None:
+    def edge_width(
+        self, edge_width: Union[int, float, np.ndarray, list]
+    ) -> None:
+        edge_width = np.broadcast_to(edge_width, self.data.shape[0]).copy()
+        if self.edge_width_is_relative and np.any(
+            (edge_width > 1) | (edge_width < 0)
+        ):
+            raise ValueError(
+                trans._(
+                    'edge_width must be between 0 and 1 if edge_width_is_relative is enabled',
+                    deferred=True,
+                )
+            )
         self._edge_width = edge_width
-        self.events.edge_width()
+        self.refresh()
+
+    @property
+    def edge_width_is_relative(self) -> bool:
+        """bool: treat edge_width as a fraction of point size."""
+        return self._edge_width_is_relative
+
+    @edge_width_is_relative.setter
+    def edge_width_is_relative(self, edge_width_is_relative: bool) -> None:
+        if edge_width_is_relative and np.any(
+            (self.edge_width > 1) | (self.edge_width < 0)
+        ):
+            raise ValueError(
+                trans._(
+                    'edge_width_is_relative can only be enabled if edge_width is between 0 and 1',
+                    deferred=True,
+                )
+            )
+        self._edge_width_is_relative = edge_width_is_relative
+        self.events.edge_width_is_relative()
+
+    @property
+    def current_edge_width(self) -> Union[int, float]:
+        """float: edge_width of marker for the next added point."""
+        return self._current_edge_width
+
+    @current_edge_width.setter
+    def current_edge_width(self, edge_width: Union[None, float]) -> None:
+        self._current_edge_width = edge_width
+        if (
+            self._update_properties
+            and len(self.selected_data) > 0
+            and self._mode != Mode.ADD
+        ):
+            for i in self.selected_data:
+                self.edge_width[i] = (self.edge_width[i] > 0) * edge_width
+            self.refresh()
+            self.events.edge_width()
 
     @property
     def edge_color(self) -> np.ndarray:
@@ -1090,6 +1149,7 @@ class Points(Layer):
             {
                 'symbol': self.symbol,
                 'edge_width': self.edge_width,
+                'edge_width_is_relative': self.edge_width_is_relative,
                 'face_color': self.face_color,
                 'face_color_cycle': self.face_color_cycle,
                 'face_colormap': self.face_colormap.name,
@@ -1147,12 +1207,23 @@ class Points(Layer):
             with self.block_update_properties():
                 self.current_face_color = face_color
 
-        size = list({self.size[i, self._dims_displayed].mean() for i in index})
+        # Calculate the mean size across the displayed dimensions for
+        # each point to be consistent with `_view_size`.
+        mean_size = np.mean(
+            self.size[np.ix_(index, self._dims_displayed)], axis=1
+        )
+        size = np.unique(mean_size)
         if len(size) == 1:
             size = size[0]
             with self.block_update_properties():
                 self.current_size = size
 
+        edge_width = np.unique(self.edge_width[index])
+        if len(edge_width) == 1:
+            edge_width = edge_width[0]
+            with self.block_update_properties():
+                self.current_edge_width = edge_width
+
         properties = {}
         for k, v in self.properties.items():
             # pandas uses `object` as dtype for strings by default, which
@@ -1283,6 +1354,9 @@ class Points(Layer):
         text : (N x 1) np.ndarray
             Array of text strings for the N text elements in view
         """
+        # This may be triggered when the string encoding instance changed,
+        # in which case it has no cached values, so generate them here.
+        self.text.string._apply(self.features)
         return self.text.view_text(self._indices_view)
 
     @property
@@ -1323,6 +1397,17 @@ class Points(Layer):
             sizes = np.array([])
         return sizes
 
+    @property
+    def _view_edge_width(self) -> np.ndarray:
+        """Get the edge_width of the points in view
+
+        Returns
+        -------
+        view_edge_width : (N,) np.ndarray
+            Array of edge_widths for the N points in view
+        """
+        return self.edge_width[self._indices_view]
+
     @property
     def _view_face_color(self) -> np.ndarray:
         """Get the face colors of the points in view
@@ -1354,6 +1439,11 @@ class Points(Layer):
         if not self.editable:
             self.mode = Mode.PAN_ZOOM
 
+        if self.ndim < 3 and self._ndisplay == 3:
+            # interaction currently does not work for 2D
+            # layers being rendered in 3D.
+            self.editable = False
+
     def _slice_data(
         self, dims_indices
     ) -> Tuple[List[int], Union[float, np.ndarray]]:
@@ -1713,13 +1803,13 @@ class Points(Layer):
         if len(index):
             self._shown = np.delete(self._shown, index, axis=0)
             self._size = np.delete(self._size, index, axis=0)
+            self._edge_width = np.delete(self._edge_width, index, axis=0)
             with self._edge.events.blocker_all():
                 self._edge._remove(indices_to_remove=index)
             with self._face.events.blocker_all():
                 self._face._remove(indices_to_remove=index)
             self._feature_table.remove(index)
-            with self.text.events.blocker_all():
-                self.text.remove(index)
+            self.text.remove(index)
             if self._value in self.selected_data:
                 self._value = None
             else:
@@ -1778,6 +1868,16 @@ class Points(Layer):
             self._size = np.append(
                 self.size, deepcopy(self._clipboard['size']), axis=0
             )
+
+            self._feature_table.append(self._clipboard['features'])
+
+            self.text._paste(**self._clipboard['text'])
+
+            self._edge_width = np.append(
+                self.edge_width,
+                deepcopy(self._clipboard['edge_width']),
+                axis=0,
+            )
             self._edge._paste(
                 colors=self._clipboard['edge_color'],
                 properties=_features_to_properties(
@@ -1791,20 +1891,12 @@ class Points(Layer):
                 ),
             )
 
-            self._feature_table.append(self._clipboard['features'])
-
             self._selected_view = list(
                 range(npoints, npoints + len(self._clipboard['data']))
             )
             self._selected_data = set(
                 range(totpoints, totpoints + len(self._clipboard['data']))
             )
-
-            if len(self._clipboard['text']) > 0:
-                self.text.values = np.concatenate(
-                    (self.text.values, self._clipboard['text']), axis=0
-                )
-
             self.refresh()
 
     def _copy_data(self):
@@ -1817,16 +1909,11 @@ class Points(Layer):
                 'face_color': deepcopy(self.face_color[index]),
                 'shown': deepcopy(self.shown[index]),
                 'size': deepcopy(self.size[index]),
+                'edge_width': deepcopy(self.edge_width[index]),
                 'features': deepcopy(self.features.iloc[index]),
                 'indices': self._slice_indices,
+                'text': self.text._copy(index),
             }
-
-            if len(self.text.values) == 0:
-                self._clipboard['text'] = np.empty(0)
-
-            else:
-                self._clipboard['text'] = deepcopy(self.text.values[index])
-
         else:
             self._clipboard = {}
 
