@@ -29,7 +29,12 @@ def select(layer, event):
             if shape_under_cursor in layer.selected_data:
                 layer.selected_data.remove(shape_under_cursor)
             else:
-                layer.selected_data.add(shape_under_cursor)
+                if len(layer.selected_data):
+                    # one or more shapes already selected
+                    layer.selected_data.add(shape_under_cursor)
+                else:
+                    # first shape being selected
+                    layer.selected_data = {shape_under_cursor}
         elif shape_under_cursor is not None:
             if shape_under_cursor not in layer.selected_data:
                 layer.selected_data = {shape_under_cursor}
@@ -394,71 +399,71 @@ def _move(layer, coordinates):
                 layer._fixed_index = (vertex + 4) % Box.LEN
                 layer._fixed_vertex = box[layer._fixed_index]
 
-            size = (
-                box[(layer._fixed_index + 4) % Box.LEN]
-                - box[layer._fixed_index]
+            handle_offset = box[Box.HANDLE] - box[Box.CENTER]
+            if np.linalg.norm(handle_offset) == 0:
+                handle_offset = [1, 1]
+            handle_offset_norm = handle_offset / np.linalg.norm(handle_offset)
+
+            rot = np.array(
+                [
+                    [handle_offset_norm[0], -handle_offset_norm[1]],
+                    [handle_offset_norm[1], handle_offset_norm[0]],
+                ]
             )
-            offset = box[Box.HANDLE] - box[Box.CENTER]
-            if np.linalg.norm(offset) == 0:
-                offset = [1, 1]
-            offset = offset / np.linalg.norm(offset)
-            offset_perp = np.array([offset[1], -offset[0]])
+            inv_rot = np.linalg.inv(rot)
 
             fixed = layer._fixed_vertex
             new = list(coord)
 
+            c = box[Box.CENTER]
             if layer._fixed_aspect and layer._fixed_index % 2 == 0:
-                if (new - fixed)[0] == 0:
-                    ratio = 1
-                else:
-                    ratio = abs((new - fixed)[1] / (new - fixed)[0])
-                if ratio > layer._aspect_ratio:
-                    r = layer._aspect_ratio / ratio
-                    new[1] = fixed[1] + (new[1] - fixed[1]) * r
-                else:
-                    r = ratio / layer._aspect_ratio
-                    new[0] = fixed[0] + (new[0] - fixed[0]) * r
-
-            if size @ offset == 0:
-                dist = 1
-            else:
-                dist = ((new - fixed) @ offset) / (size @ offset)
-
-            if size @ offset_perp == 0:
-                dist_perp = 1
-            else:
-                dist_perp = ((new - fixed) @ offset_perp) / (
-                    size @ offset_perp
-                )
+                # corner
+                new = (box[vertex] - c) / np.linalg.norm(
+                    box[vertex] - c
+                ) * np.linalg.norm(new - c) + c
 
             if layer._fixed_index % 2 == 0:
                 # corner selected
-                scale = np.array([dist_perp, dist])
+                scale = (inv_rot @ (new - fixed)) / (
+                    inv_rot @ (box[vertex] - fixed)
+                )
             elif layer._fixed_index % 4 == 3:
-                # top selected
-                scale = np.array([1, dist])
+                # top or bottom selected
+                scale = np.array(
+                    [
+                        (inv_rot @ (new - fixed))[0]
+                        / (inv_rot @ (box[vertex] - fixed))[0],
+                        1,
+                    ]
+                )
             else:
-                # side selected
-                scale = np.array([dist_perp, 1])
+                # left or right selected
+                scale = np.array(
+                    [
+                        1,
+                        (inv_rot @ (new - fixed))[1]
+                        / (inv_rot @ (box[vertex] - fixed))[1],
+                    ]
+                )
 
             # prevent box from shrinking below a threshold size
-            threshold = layer._vertex_size * layer.scale_factor / 8
-            scale[abs(scale * size[[1, 0]]) < threshold] = 1
+            size = [
+                np.linalg.norm(box[Box.TOP_CENTER] - c),
+                np.linalg.norm(box[Box.LEFT_CENTER] - c),
+            ]
+            threshold = layer._vertex_size * layer.scale_factor / 2
+            scale[abs(scale * size) < threshold] = 1
 
             # check orientation of box
-            angle = -np.arctan2(offset[0], -offset[1])
-            c, s = np.cos(angle), np.sin(angle)
-            if angle == 0:
+            if abs(handle_offset_norm[0]) == 1:
                 for index in layer.selected_data:
                     layer._data_view.scale(
                         index, scale, center=layer._fixed_vertex
                     )
                 layer._scale_box(scale, center=layer._fixed_vertex)
             else:
-                rotation = np.array([[c, s], [-s, c]])
                 scale_mat = np.array([[scale[0], 0], [0, scale[1]]])
-                inv_rot = np.array([[c, -s], [s, c]])
-                transform = rotation @ scale_mat @ inv_rot
+                transform = rot @ scale_mat @ inv_rot
                 for index in layer.selected_data:
                     layer._data_view.shift(index, -layer._fixed_vertex)
                     layer._data_view.transform(index, transform)
