@@ -73,12 +73,12 @@ class Surface(IntensityVisualizationMixin, Layer):
         One of a list of preset shading modes that determine the lighting model
         using when rendering the surface in 3D.
 
-        * Shading.NONE
-            Corresponds to shading='none'.
-        * Shading.FLAT
-            Corresponds to shading='flat'.
-        * Shading.SMOOTH
-            Corresponds to shading='smooth'.
+        * ``Shading.NONE``
+          Corresponds to ``shading='none'``.
+        * ``Shading.FLAT``
+          Corresponds to ``shading='flat'``.
+        * ``Shading.SMOOTH``
+          Corresponds to ``shading='smooth'``.
     visible : bool
         Whether the layer visual is currently being displayed.
     cache : bool
@@ -118,9 +118,9 @@ class Surface(IntensityVisualizationMixin, Layer):
         One of a list of preset shading modes that determine the lighting model
         using when rendering the surface.
 
-        * 'none'
-        * 'flat'
-        * 'smooth'
+        * ``'none'``
+        * ``'flat'``
+        * ``'smooth'``
     gamma : float
         Gamma correction for determining colormap linearity.
     wireframe : SurfaceWireframe
