@@ -1,25 +1,20 @@
 import warnings
 from copy import copy
-from typing import Dict, Tuple, Union
+from typing import Dict, List, Tuple, Union
 
 import numpy as np
+import pandas as pd
 
-from ...utils.colormaps import Colormap, ValidColormapArg, ensure_colormap
+from ...utils.colormaps import Colormap, ValidColormapArg
 from ...utils.events import Event
-from ...utils.status_messages import format_float
+from ...utils.events.custom_types import Array
+from ...utils.translations import trans
 from ..base import Layer
-from ..utils.color_transformations import (
-    normalize_and_broadcast_colors,
-    transform_color_cycle,
-    transform_color_with_defaults,
-)
-from ..utils.layer_utils import (
-    dataframe_to_properties,
-    guess_continuous,
-    map_property,
-)
-from ._vector_utils import generate_vector_meshes, vectors_to_coordinates
-from ._vectors_constants import DEFAULT_COLOR_CYCLE, ColorMode
+from ..utils._color_manager_constants import ColorMode
+from ..utils.color_manager import ColorManager
+from ..utils.color_transformations import ColorType
+from ..utils.layer_utils import _FeatureTable
+from ._vector_utils import fix_data_vectors, generate_vector_meshes
 
 
 class Vectors(Layer):
@@ -34,13 +29,21 @@ class Vectors(Layer):
         D dimensions. An (N1, N2, ..., ND, D) array is interpreted as
         "image-like" data where there is a length D vector of the
         projections at each pixel.
+    ndim : int
+        Number of dimensions for vectors. When data is not None, ndim must be D.
+        An empty vectors layer can be instantiated with arbitrary ndim.
+    features : dict[str, array-like] or DataFrame
+        Features table where each row corresponds to a vector and each column
+        is a feature.
     properties : dict {str: array (N,)}, DataFrame
         Properties for each vector. Each property should be an array of length N,
         where N is the number of vectors.
+    property_choices : dict {str: array (N,)}
+        possible values for each property.
     edge_width : float
         Width for all vectors in pixels.
     length : float
-         Multiplicative factor on projections for length of all vectors.
+        Multiplicative factor on projections for length of all vectors.
     edge_color : str
         Color of all of the vectors.
     edge_color_cycle : np.ndarray, list
@@ -53,6 +56,9 @@ class Vectors(Layer):
         of the specified property that are mapped to 0 and 1, respectively.
         The default value is None. If set the none, the clims will be set to
         (property.min(), property.max())
+    out_of_slice_display : bool
+        If True, renders vectors not just in central plane but also slightly out of slice
+        according to specified point marker size.
     name : str
         Name of the layer.
     metadata : dict
@@ -61,6 +67,21 @@ class Vectors(Layer):
         Scale factors for the layer.
     translate : tuple of float
         Translation values for the layer.
+    rotate : float, 3-tuple of float, or n-D array.
+        If a float convert into a 2D rotation matrix using that value as an
+        angle. If 3-tuple convert into a 3D rotation matrix, using a yaw,
+        pitch, roll convention. Otherwise assume an nD rotation. Angles are
+        assumed to be in degrees. They can be converted from radians with
+        np.degrees if needed.
+    shear : 1-D array or n-D array
+        Either a vector of upper triangular values, or an nD shear matrix with
+        ones along the main diagonal.
+    affine : n-D array or napari.utils.transforms.Affine
+        (N+1, N+1) affine transformation matrix in homogeneous coordinates.
+        The first (N, N) entries correspond to a linear transform and
+        the final column is a length N translation vector and a 1 or a napari
+        `Affine` transform object. Applied as an extra transform on top of the
+        provided scale, rotate, and shear values.
     opacity : float
         Opacity of the layer visual, between 0.0 and 1.0.
     blending : str
@@ -69,18 +90,26 @@ class Vectors(Layer):
         {'opaque', 'translucent', and 'additive'}.
     visible : bool
         Whether the layer visual is currently being displayed.
+    cache : bool
+        Whether slices of out-of-core datasets should be cached upon retrieval.
+        Currently, this only applies to dask arrays.
 
     Attributes
     ----------
     data : (N, 2, D) array
         The start point and projections of N vectors in D dimensions.
+    features : Dataframe-like
+        Features table where each row corresponds to a vector and each column
+        is a feature.
+    feature_defaults : DataFrame-like
+        Stores the default value of each feature in a table with one row.
     properties : dict {str: array (N,)}, DataFrame
         Properties for each vector. Each property should be an array of length N,
         where N is the number of vectors.
     edge_width : float
         Width for all vectors in pixels.
     length : float
-         Multiplicative factor on projections for length of all vectors.
+        Multiplicative factor on projections for length of all vectors.
     edge_color : str
         Color of all of the vectors.
     edge_color_cycle : np.ndarray, list
@@ -93,9 +122,12 @@ class Vectors(Layer):
         of the specified property that are mapped to 0 and 1, respectively.
         The default value is None. If set the none, the clims will be set to
         (property.min(), property.max())
+    out_of_slice_display : bool
+        If True, renders vectors not just in central plane but also slightly out of slice
+        according to specified point marker size.
 
-    Extended Summary
-    ----------
+    Notes
+    -----
     _view_data : (M, 2, 2) array
         The start point and projections of N vectors in 2D for vectors whose
         start point is in the currently viewed slice.
@@ -108,9 +140,10 @@ class Vectors(Layer):
     _view_faces : (2M, 3) or (4M, 3) np.ndarray
         indices of the _mesh_vertices that form the faces of the M in view vectors.
         Shape is (2M, 2) for 2D and (4M, 2) for 3D.
+    _view_alphas : (M,) or float
+        relative opacity for the M in view vectors
     _property_choices : dict {str: array (N,)}
         Possible values for the properties in Vectors.properties.
-        If properties is not provided, it will be {} (empty dictionary).
     _mesh_vertices : (4N, 2) array
         The four corner points for the mesh representation of each vector as as
         rectangle in the slice that it starts in.
@@ -129,34 +162,52 @@ class Vectors(Layer):
 
     def __init__(
         self,
-        data,
+        data=None,
         *,
+        ndim=None,
+        features=None,
         properties=None,
+        property_choices=None,
         edge_width=1,
         edge_color='red',
         edge_color_cycle=None,
         edge_colormap='viridis',
         edge_contrast_limits=None,
+        out_of_slice_display=False,
         length=1,
         name=None,
         metadata=None,
         scale=None,
         translate=None,
+        rotate=None,
+        shear=None,
+        affine=None,
         opacity=0.7,
         blending='translucent',
         visible=True,
+        cache=True,
+        experimental_clipping_planes=None,
     ):
+        if ndim is None and scale is not None:
+            ndim = len(scale)
+
+        data, ndim = fix_data_vectors(data, ndim)
 
         super().__init__(
             data,
-            2,
+            ndim,
             name=name,
             metadata=metadata,
             scale=scale,
             translate=translate,
+            rotate=rotate,
+            shear=shear,
+            affine=affine,
             opacity=opacity,
             blending=blending,
             visible=visible,
+            cache=cache,
+            experimental_clipping_planes=experimental_clipping_planes,
         )
 
         # events for non-napari calculations
@@ -165,50 +216,46 @@ class Vectors(Layer):
             edge_width=Event,
             edge_color=Event,
             edge_color_mode=Event,
+            properties=Event,
+            out_of_slice_display=Event,
+            features=Event,
+            feature_defaults=Event,
         )
 
-        self.visible = False
-
         # Save the vector style params
         self._edge_width = edge_width
+        self._out_of_slice_display = out_of_slice_display
 
-        # length attribute
-        self._length = length
+        self._length = float(length)
 
-        self.data = data
+        self._data = data
 
-        # Save the properties
-        if properties is None:
-            self._properties = {}
-            self._property_choices = {}
-        elif len(data) > 0:
-            properties, _ = dataframe_to_properties(properties)
-            self._properties = self._validate_properties(properties)
-            self._property_choices = {
-                k: np.unique(v) for k, v in properties.items()
-            }
-        elif len(data) == 0:
-            self._property_choices = {
-                k: np.asarray(v) for k, v in properties.items()
-            }
-            empty_properties = {
-                k: np.empty(0, dtype=v.dtype)
-                for k, v in self._property_choices.items()
-            }
-            self._properties = empty_properties
+        vertices, triangles = generate_vector_meshes(
+            self._data[:, :, list(self._dims_displayed)],
+            self.edge_width,
+            self.length,
+        )
+        self._mesh_vertices = vertices
+        self._mesh_triangles = triangles
+        self._displayed_stored = copy(self._dims_displayed)
 
-        with self.block_update_properties():
-            self._edge_color_property = ''
-            self._edge_color_mode = ColorMode.DIRECT
-            self.edge_color = edge_color
-            if edge_color_cycle is None:
-                edge_color_cycle = DEFAULT_COLOR_CYCLE
-            self.edge_color_cycle = edge_color_cycle
-            self.edge_color_cycle_map = {}
-            self.edge_colormap = edge_colormap
-            self._edge_contrast_limits = edge_contrast_limits
+        self._feature_table = _FeatureTable.from_layer(
+            features=features,
+            properties=properties,
+            property_choices=property_choices,
+            num_data=len(self.data),
+        )
 
-        self.refresh_colors()
+        self._edge = ColorManager._from_layer_kwargs(
+            n_colors=len(self.data),
+            colors=edge_color,
+            continuous_colormap=edge_colormap,
+            contrast_limits=edge_contrast_limits,
+            categorical_colormap=edge_color_cycle,
+            properties=self.properties
+            if self._data.size > 0
+            else self.property_choices,
+        )
 
         # Data containing vectors in the currently viewed slice
         self._view_data = np.empty((0, 2, 2))
@@ -216,8 +263,10 @@ class Vectors(Layer):
         self._view_vertices = []
         self._view_faces = []
         self._view_indices = []
+        self._view_alphas = []
 
         # now that everything is set up, make the layer visible (if set to visible)
+        self._update_dims()
         self.visible = visible
 
     @property
@@ -227,47 +276,108 @@ class Vectors(Layer):
 
     @data.setter
     def data(self, vectors: np.ndarray):
-        self._data = vectors_to_coordinates(vectors)
+        previous_n_vectors = len(self.data)
+
+        self._data, _ = fix_data_vectors(vectors, self.ndim)
+        n_vectors = len(self.data)
 
         vertices, triangles = generate_vector_meshes(
-            self._data[:, :, list(self.dims.displayed)],
+            self._data[:, :, list(self._dims_displayed)],
             self.edge_width,
             self.length,
         )
         self._mesh_vertices = vertices
         self._mesh_triangles = triangles
-        self._displayed_stored = copy(self.dims.displayed)
+        self._displayed_stored = copy(self._dims_displayed)
+
+        # Adjust the props/color arrays when the number of vectors has changed
+        with self.events.blocker_all():
+            with self._edge.events.blocker_all():
+                self._feature_table.resize(n_vectors)
+                if n_vectors < previous_n_vectors:
+                    # If there are now fewer points, remove the size and colors of the
+                    # extra ones
+                    if len(self._edge.colors) > n_vectors:
+                        self._edge._remove(
+                            np.arange(n_vectors, len(self._edge.colors))
+                        )
+
+                elif n_vectors > previous_n_vectors:
+                    # If there are now more points, add the size and colors of the
+                    # new ones
+                    adding = n_vectors - previous_n_vectors
+                    self._edge._add(n_colors=adding)
 
         self._update_dims()
-        self.events.data()
+        self.events.data(value=self.data)
+        self._set_editable()
+
+    @property
+    def features(self):
+        """Dataframe-like features table.
+
+        It is an implementation detail that this is a `pandas.DataFrame`. In the future,
+        we will target the currently-in-development Data API dataframe protocol [1].
+        This will enable us to use alternate libraries such as xarray or cuDF for
+        additional features without breaking existing usage of this.
+
+        If you need to specifically rely on the pandas API, please coerce this to a
+        `pandas.DataFrame` using `features_to_pandas_dataframe`.
+
+        References
+        ----------
+        .. [1]: https://data-apis.org/dataframe-protocol/latest/API.html
+        """
+        return self._feature_table.values
+
+    @features.setter
+    def features(
+        self,
+        features: Union[Dict[str, np.ndarray], pd.DataFrame],
+    ) -> None:
+        self._feature_table.set_values(features, num_data=len(self.data))
+        if self._edge.color_properties is not None:
+            if self._edge.color_properties.name not in self.features:
+                self._edge.color_mode = ColorMode.DIRECT
+                self._edge.color_properties = None
+                warnings.warn(
+                    trans._(
+                        'property used for edge_color dropped',
+                        deferred=True,
+                    ),
+                    RuntimeWarning,
+                )
+            else:
+                edge_color_name = self._edge.color_properties.name
+                property_values = self.features[edge_color_name].to_numpy()
+                self._edge.color_properties = {
+                    'name': edge_color_name,
+                    'values': property_values,
+                    'current_value': self.feature_defaults[edge_color_name][0],
+                }
+        self.events.properties()
+        self.events.features()
 
     @property
     def properties(self) -> Dict[str, np.ndarray]:
         """dict {str: array (N,)}, DataFrame: Annotations for each point"""
-        return self._properties
+        return self._feature_table.properties()
 
     @properties.setter
-    def properties(self, properties: Dict[str, np.ndarray]):
-        if not isinstance(properties, dict):
-            properties, _ = dataframe_to_properties(properties)
-        self._properties = self._validate_properties(properties)
-        if self._edge_color_property and (
-            self._edge_color_property not in self._properties
-        ):
-            self._edge_color_property = ''
-            warnings.warn('property used for edge_color dropped')
+    def properties(self, properties: Dict[str, Array]):
+        self.features = properties
 
-    def _validate_properties(
-        self, properties: Dict[str, np.ndarray]
-    ) -> Dict[str, np.ndarray]:
-        """Validates the type and size of the properties"""
-        for v in properties.values():
-            if len(v) != len(self.data):
-                raise ValueError(
-                    'the number of properties must equal the number of points'
-                )
+    @property
+    def feature_defaults(self):
+        """Dataframe-like with one row of feature default values.
 
-        return properties
+        See `features` for more details on the type of this property.
+        """
+        return self._feature_table.defaults
+
+    @property
+    def property_choices(self) -> Dict[str, np.ndarray]:
+        return self._feature_table.choices()
 
     def _get_state(self):
         """Get dictionary of layer state.
@@ -288,6 +398,10 @@ class Vectors(Layer):
                 'edge_contrast_limits': self.edge_contrast_limits,
                 'data': self.data,
                 'properties': self.properties,
+                'property_choices': self.property_choices,
+                'ndim': self.ndim,
+                'features': self.features,
+                'out_of_slice_display': self.out_of_slice_display,
             }
         )
         return state
@@ -315,6 +429,17 @@ class Vectors(Layer):
             extrema = np.vstack([mins, maxs])
         return extrema
 
+    @property
+    def out_of_slice_display(self) -> bool:
+        """bool: renders vectors slightly out of slice."""
+        return self._out_of_slice_display
+
+    @out_of_slice_display.setter
+    def out_of_slice_display(self, out_of_slice_display: bool) -> None:
+        self._out_of_slice_display = out_of_slice_display
+        self.events.out_of_slice_display()
+        self.refresh()
+
     @property
     def edge_width(self) -> Union[int, float]:
         """float: Width for all vectors in pixels."""
@@ -325,17 +450,16 @@ class Vectors(Layer):
         self._edge_width = edge_width
 
         vertices, triangles = generate_vector_meshes(
-            self.data[:, :, list(self.dims.displayed)],
+            self.data[:, :, list(self._dims_displayed)],
             self._edge_width,
             self.length,
         )
         self._mesh_vertices = vertices
         self._mesh_triangles = triangles
-        self._displayed_stored = copy(self.dims.displayed)
+        self._displayed_stored = copy(self._dims_displayed)
 
         self.events.edge_width()
         self.refresh()
-        self.status = format_float(self.edge_width)
 
     @property
     def length(self) -> Union[int, float]:
@@ -344,63 +468,34 @@ class Vectors(Layer):
 
     @length.setter
     def length(self, length: Union[int, float]):
-        self._length = length
+        self._length = float(length)
 
         vertices, triangles = generate_vector_meshes(
-            self.data[:, :, list(self.dims.displayed)],
+            self.data[:, :, list(self._dims_displayed)],
             self.edge_width,
             self._length,
         )
         self._mesh_vertices = vertices
         self._mesh_triangles = triangles
-        self._displayed_stored = copy(self.dims.displayed)
+        self._displayed_stored = copy(self._dims_displayed)
 
         self.events.length()
         self.refresh()
-        self.status = format_float(self.length)
 
     @property
     def edge_color(self) -> np.ndarray:
         """(1 x 4) np.ndarray: Array of RGBA edge colors (applied to all vectors)"""
-        return self._edge_color
+        return self._edge.colors
 
     @edge_color.setter
-    def edge_color(self, edge_color: str):
-        # save the old mode, we will emit an event if the mode has changed
-        old_mode = self._edge_color_mode
-
-        # if the provided face color is a string, first check if it is a key in the properties.
-        # otherwise, assume it is the name of a color
-        if self._is_color_mapped(edge_color):
-            if guess_continuous(self.properties[edge_color]):
-                new_mode = ColorMode.COLORMAP
-                self._edge_color_mode = new_mode
-            else:
-                new_mode = ColorMode.CYCLE
-                self._edge_color_mode = new_mode
-            self._edge_color_property = edge_color
-            self.refresh_colors()
-
-        else:
-            transformed_color = transform_color_with_defaults(
-                num_entries=len(self.data),
-                colors=edge_color,
-                elem_name="edge_color",
-                default="white",
-            )
-            self._edge_color = normalize_and_broadcast_colors(
-                len(self.data), transformed_color
-            )
-            new_mode = ColorMode.DIRECT
-            self._edge_color_mode = new_mode
-            self._edge_color_property = ''
-
-            self.events.edge_color()
-
-            if self.visible:
-                self._update_thumbnail()
-        if new_mode != old_mode:
-            self.events.edge_color_mode()
+    def edge_color(self, edge_color: ColorType):
+        self._edge._set_color(
+            color=edge_color,
+            n_colors=len(self.data),
+            properties=self.properties,
+            current_properties=self._feature_table.currents(),
+        )
+        self.events.edge_color()
 
     def refresh_colors(self, update_color_mapping: bool = False):
         """Calculate and update edge colors if using a cycle or color map
@@ -416,83 +511,7 @@ class Vectors(Layer):
             the color cycle map or colormap), set update_color_mapping=False.
             Default value is False.
         """
-        if self._update_properties:
-            if self._edge_color_mode == ColorMode.CYCLE:
-                edge_color_properties = self.properties[
-                    self._edge_color_property
-                ]
-                if update_color_mapping:
-                    self.edge_color_cycle_map = {
-                        k: c
-                        for k, c in zip(
-                            np.unique(edge_color_properties),
-                            self._edge_color_cycle,
-                        )
-                    }
-                else:
-                    # add properties if they are not in the colormap
-                    # and update_color_mapping==False
-                    edge_color_cycle_keys = [*self.edge_color_cycle_map]
-                    props_in_map = np.in1d(
-                        edge_color_properties, edge_color_cycle_keys
-                    )
-                    if not np.all(props_in_map):
-                        props_to_add = np.unique(
-                            edge_color_properties[np.logical_not(props_in_map)]
-                        )
-                        for prop in props_to_add:
-                            self.edge_color_cycle_map[prop] = next(
-                                self._edge_color_cycle
-                            )
-                edge_colors = np.array(
-                    [
-                        self.edge_color_cycle_map[x]
-                        for x in edge_color_properties
-                    ]
-                )
-                if len(edge_colors) == 0:
-                    edge_colors = np.empty((0, 4))
-                self._edge_color = edge_colors
-            elif self._edge_color_mode == ColorMode.COLORMAP:
-                edge_color_properties = self.properties[
-                    self._edge_color_property
-                ]
-                if len(edge_color_properties) > 0:
-                    if (
-                        update_color_mapping
-                        or self.edge_contrast_limits is None
-                    ):
-                        edge_colors, contrast_limits = map_property(
-                            prop=edge_color_properties,
-                            colormap=self.edge_colormap,
-                        )
-                        self.edge_contrast_limits = contrast_limits
-                    else:
-                        edge_colors, _ = map_property(
-                            prop=edge_color_properties,
-                            colormap=self.edge_colormap,
-                            contrast_limits=self.edge_contrast_limits,
-                        )
-                else:
-                    edge_colors = np.empty((0, 4))
-                self._edge_color = edge_colors
-            self.events.edge_color()
-            if self.visible:
-                self._update_thumbnail()
-
-    def _is_color_mapped(self, color) -> bool:
-        """ determines if the new color argument is for directly setting or cycle/colormap"""
-        if isinstance(color, str):
-            if color in self.properties:
-                return True
-            else:
-                return False
-        elif isinstance(color, (list, np.ndarray)):
-            return False
-        else:
-            raise ValueError(
-                'edge_color should be the name of a color, an array of colors, or the name of an property'
-            )
+        self._edge._refresh_colors(self.properties, update_color_mapping)
 
     @property
     def edge_color_mode(self) -> ColorMode:
@@ -504,7 +523,7 @@ class Vectors(Layer):
 
         COLORMAP allows color to be set via a color map over an attribute
         """
-        return str(self._edge_color_mode)
+        return self._edge.color_mode
 
     @edge_color_mode.setter
     def edge_color_mode(self, edge_color_mode: Union[str, ColorMode]):
@@ -513,30 +532,50 @@ class Vectors(Layer):
         if edge_color_mode == ColorMode.DIRECT:
             self._edge_color_mode = edge_color_mode
         elif edge_color_mode in (ColorMode.CYCLE, ColorMode.COLORMAP):
-            if self._edge_color_property == '':
+            if self._edge.color_properties is not None:
+                color_property = self._edge.color_properties.name
+            else:
+                color_property = ''
+            if color_property == '':
                 if self.properties:
-                    self._edge_color_property = next(iter(self.properties))
-                    warning_msg = (
-                        'edge_color_property was not set, setting to: %s'
-                        % self._edge_color_property
+                    color_property = next(iter(self.properties))
+                    self._edge.color_properties = {
+                        'name': color_property,
+                        'values': self.features[color_property].to_numpy(),
+                        'current_value': self.feature_defaults[color_property][
+                            0
+                        ],
+                    }
+                    warnings.warn(
+                        trans._(
+                            'edge_color property was not set, setting to: {color_property}',
+                            deferred=True,
+                            color_property=color_property,
+                        ),
+                        RuntimeWarning,
                     )
-                    warnings.warn(warning_msg, RuntimeWarning)
                 else:
                     raise ValueError(
-                        'There must valid properties to use %s color mode'
-                        % str(edge_color_mode)
+                        trans._(
+                            'There must be a valid Points.properties to use {edge_color_mode}',
+                            deferred=True,
+                            edge_color_mode=edge_color_mode,
+                        )
                     )
+
             # ColorMode.COLORMAP can only be applied to numeric properties
             if (edge_color_mode == ColorMode.COLORMAP) and not issubclass(
-                self.properties[self._edge_color_property].dtype.type,
+                self.properties[color_property].dtype.type,
                 np.number,
             ):
                 raise TypeError(
-                    'selected property must be numeric to use ColorMode.COLORMAP'
+                    trans._(
+                        'selected property must be numeric to use ColorMode.COLORMAP',
+                        deferred=True,
+                    )
                 )
 
-            self._edge_color_mode = edge_color_mode
-            self.refresh_colors()
+            self._edge.color_mode = edge_color_mode
         self.events.edge_color_mode()
 
     @property
@@ -544,19 +583,11 @@ class Vectors(Layer):
         """list, np.ndarray :  Color cycle for edge_color.
         Can be a list of colors defined by name, RGB or RGBA
         """
-        return self._edge_color_cycle_values
+        return self._edge.categorical_colormap.fallback_color.values
 
     @edge_color_cycle.setter
     def edge_color_cycle(self, edge_color_cycle: Union[list, np.ndarray]):
-        transformed_color_cycle, transformed_colors = transform_color_cycle(
-            color_cycle=edge_color_cycle,
-            elem_name='edge_color_cycle',
-            default="white",
-        )
-        self._edge_color_cycle_values = transformed_colors
-        self._edge_color_cycle = transformed_color_cycle
-        if self._edge_color_mode == ColorMode.CYCLE:
-            self.refresh_colors(update_color_mapping=True)
+        self._edge.categorical_colormap = edge_color_cycle
 
     @property
     def edge_colormap(self) -> Tuple[str, Colormap]:
@@ -567,68 +598,116 @@ class Vectors(Layer):
         colormap : napari.utils.Colormap
             The Colormap object.
         """
-        return self._edge_colormap
+        return self._edge.continuous_colormap
 
     @edge_colormap.setter
     def edge_colormap(self, colormap: ValidColormapArg):
-        self._edge_colormap = ensure_colormap(colormap)
+        self._edge.continuous_colormap = colormap
 
     @property
     def edge_contrast_limits(self) -> Tuple[float, float]:
-        """ None, (float, float): contrast limits for mapping
+        """None, (float, float): contrast limits for mapping
         the edge_color colormap property to 0 and 1
         """
-        return self._edge_contrast_limits
+        return self._edge.contrast_limits
 
     @edge_contrast_limits.setter
     def edge_contrast_limits(
         self, contrast_limits: Union[None, Tuple[float, float]]
     ):
-        self._edge_contrast_limits = contrast_limits
+        self._edge.contrast_limits = contrast_limits
 
     @property
     def _view_face_color(self) -> np.ndarray:
-        """" (Mx4) np.ndarray : colors for the M in view vectors"""
-        face_color = np.repeat(self.edge_color[self._view_indices], 2, axis=0)
-        if self.dims.ndisplay == 3 and self.ndim > 2:
+        """(Mx4) np.ndarray : colors for the M in view vectors"""
+        face_color = self.edge_color[self._view_indices]
+        face_color[:, -1] *= self._view_alphas
+        face_color = np.repeat(face_color, 2, axis=0)
+
+        if self._ndisplay == 3 and self.ndim > 2:
             face_color = np.vstack([face_color, face_color])
 
         return face_color
 
+    def _slice_data(
+        self, dims_indices
+    ) -> Tuple[List[int], Union[float, np.ndarray]]:
+        """Determines the slice of vectors given the indices.
+
+        Parameters
+        ----------
+        dims_indices : sequence of int or slice
+            Indices to slice with.
+
+        Returns
+        -------
+        slice_indices : list
+            Indices of vectors in the currently viewed slice.
+        alpha : float, (N, ) array
+            The computed, relative opacity of vectors in the current slice.
+            If `out_of_slice_display` is mode is off, this is always 1.
+            Otherwise, vectors originating in the current slice are assigned a value of 1,
+            while vectors passing through the current slice are assigned progressively lower
+            values, based on how far from the current slice they originate.
+        """
+        not_disp = list(self._dims_not_displayed)
+        indices = np.array(dims_indices)
+        if len(self.data) > 0:
+            data = self.data[:, 0, not_disp]
+            distances = abs(data - indices[not_disp])
+            if self.out_of_slice_display is True:
+                projected_lengths = abs(
+                    self.data[:, 1, not_disp] * self.length
+                )
+                matches = np.all(distances <= projected_lengths, axis=1)
+                alpha_match = projected_lengths[matches]
+                alpha_match[alpha_match == 0] = 1
+                alpha_per_dim = (
+                    alpha_match - distances[matches]
+                ) / alpha_match
+                alpha_per_dim[alpha_match == 0] = 1
+                alpha = np.prod(alpha_per_dim, axis=1).astype(float)
+            else:
+                matches = np.all(distances <= 0.5, axis=1)
+                alpha = 1.0
+
+            slice_indices = np.where(matches)[0].astype(int)
+            return slice_indices, alpha
+        else:
+            return [], np.empty(0)
+
     def _set_view_slice(self):
         """Sets the view given the indices to slice with."""
 
-        if not self.dims.displayed == self._displayed_stored:
+        indices, alphas = self._slice_data(self._slice_indices)
+        if not self._dims_displayed == self._displayed_stored:
             vertices, triangles = generate_vector_meshes(
-                self.data[:, :, list(self.dims.displayed)],
+                self.data[:, :, list(self._dims_displayed)],
                 self.edge_width,
                 self.length,
             )
             self._mesh_vertices = vertices
             self._mesh_triangles = triangles
-            self._displayed_stored = copy(self.dims.displayed)
+            self._displayed_stored = copy(self._dims_displayed)
 
         vertices = self._mesh_vertices
-        not_disp = list(self.dims.not_displayed)
-        disp = list(self.dims.displayed)
-        indices = np.array(self._slice_indices)
+        disp = list(self._dims_displayed)
 
         if len(self.data) == 0:
             faces = []
             self._view_data = np.empty((0, 2, 2))
             self._view_indices = []
         elif self.ndim > 2:
-            data = self.data[:, 0, not_disp].astype('int')
-            matches = np.all(data == indices[not_disp], axis=1)
-            matches = np.where(matches)[0]
-            self._view_indices = matches
-            self._view_data = self.data[np.ix_(matches, [0, 1], disp)]
-            if len(matches) == 0:
+            indices, alphas = self._slice_data(self._slice_indices)
+            self._view_indices = indices
+            self._view_alphas = alphas
+            self._view_data = self.data[np.ix_(indices, [0, 1], disp)]
+            if len(indices) == 0:
                 faces = []
             else:
-                keep_inds = np.repeat(2 * matches, 2)
+                keep_inds = np.repeat(2 * indices, 2)
                 keep_inds[1::2] = keep_inds[1::2] + 1
-                if self.dims.ndisplay == 3:
+                if self._ndisplay == 3:
                     keep_inds = np.concatenate(
                         [
                             keep_inds,
@@ -641,6 +720,7 @@ class Vectors(Layer):
             faces = self._mesh_triangles
             self._view_data = self.data[:, :, disp]
             self._view_indices = np.arange(self.data.shape[0])
+            self._view_alphas = 1.0
 
         if len(faces) == 0:
             self._view_vertices = []
@@ -655,12 +735,14 @@ class Vectors(Layer):
         # the offset is needed to ensure that the top left corner of the
         # vectors corresponds to the top left corner of the thumbnail
         de = self._extent_data
-        offset = (np.array([de[0, d] for d in self.dims.displayed]) + 0.5)[-2:]
+        offset = (np.array([de[0, d] for d in self._dims_displayed]) + 0.5)[
+            -2:
+        ]
         # calculate range of values for the vertices and pad with 1
         # padding ensures the entire vector can be represented in the thumbnail
         # without getting clipped
         shape = np.ceil(
-            [de[1, d] - de[0, d] + 1 for d in self.dims.displayed]
+            [de[1, d] - de[0, d] + 1 for d in self._dims_displayed]
         ).astype(int)[-2:]
         zoom_factor = np.divide(self._thumbnail_shape[:2], shape).min()
 
@@ -681,7 +763,7 @@ class Vectors(Layer):
         )
         colormapped = np.zeros(self._thumbnail_shape)
         colormapped[..., 3] = 1
-        edge_colors = self.edge_color[thumbnail_color_indices]
+        edge_colors = self._edge.colors[thumbnail_color_indices]
         for v, ec in zip(downsampled, edge_colors):
             start = v[0]
             stop = v[1]
@@ -693,14 +775,17 @@ class Vectors(Layer):
         colormapped[..., 3] *= self.opacity
         self.thumbnail = colormapped
 
-    def _get_value(self) -> None:
-        """Returns coordinates, values, and a string for a given mouse position
-        and set of indices.
+    def _get_value(self, position):
+        """Value of the data at a position in data coordinates.
+
+        Parameters
+        ----------
+        position : tuple
+            Position in data coordinates.
 
         Returns
         -------
-        value : int, None
+        value : None
             Value of the data at the coord.
         """
-
         return None
