@@ -1,6 +1,9 @@
 import os
+
 import numpy as np
 
+from napari._tests.utils import assert_layer_state_equal
+
 
 # the layer_writer_and_data fixture is defined in napari/conftest.py
 def test_write_layer_with_round_trip(tmpdir, layer_writer_and_data):
@@ -38,8 +41,9 @@ def test_write_layer_with_round_trip(tmpdir, layer_writer_and_data):
     else:
         np.testing.assert_allclose(layer_data[0], read_layer_data[0])
 
-    # # Compare layer metadata
-    np.testing.assert_equal(layer_data[1], read_layer_data[1])
+    # Compare layer metadata
+    assert_layer_state_equal(layer_data[1], read_layer_data[1])
+
     # Compare layer type
     assert layer_data[2] == read_layer_data[2]
 
