@@ -1,14 +1,16 @@
+from enum import Enum
 from typing import Dict, List, Set
 
 from pydantic import Field
 from typing_extensions import TypedDict
 
 from ..utils.events.evented_model import EventedModel
+from ..utils.misc import running_as_bundled_app, running_as_constructor_app
 from ..utils.translations import trans
 
 
 class PluginHookOption(TypedDict):
-    """Custom type specifying plugin and enabled state."""
+    """Custom type specifying plugin, hook implementation function name, and enabled state."""
 
     plugin: str
     enabled: bool
@@ -17,7 +19,19 @@ class PluginHookOption(TypedDict):
 CallOrderDict = Dict[str, List[PluginHookOption]]
 
 
+class PluginAPI(str, Enum):
+    napari_hub = 'napari hub'
+    pypi = 'PyPI'
+
+
 class PluginsSettings(EventedModel):
+    plugin_api: PluginAPI = Field(
+        PluginAPI.napari_hub,
+        title=trans._("Plugin API"),
+        description=trans._(
+            "Use the following API for querying plugin information.",
+        ),
+    )
     call_order: CallOrderDict = Field(
         default_factory=dict,
         title=trans._("Plugin sort order"),
@@ -47,6 +61,9 @@ class PluginsSettings(EventedModel):
         ),
     )
 
+    class Config:
+        use_enum_values = False
+
     class NapariConfig:
         # Napari specific configuration
         preferences_exclude = [
@@ -54,3 +71,6 @@ class PluginsSettings(EventedModel):
             'disabled_plugins',
             'extension2writer',
         ]
+
+        if running_as_bundled_app() or running_as_constructor_app():
+            preferences_exclude.append('plugin_api')
