@@ -9,11 +9,11 @@ import pytest
 from napari.utils.notifications import (
     Notification,
     notification_manager,
+    show_error,
     show_info,
+    show_warning,
 )
 
-PY38_OR_HIGHER = bool(getattr(threading, 'excepthook', None))
-
 
 # capsys fixture comes from pytest
 # https://docs.pytest.org/en/stable/logging.html#caplog-fixture
@@ -45,7 +45,7 @@ def test_notification_manager_no_gui(monkeypatch):
         from napari._qt.dialogs.qt_notification import NapariQtNotification
 
         monkeypatch.setattr(NapariQtNotification, "DISMISS_AFTER", 0)
-    except ImportError:
+    except ModuleNotFoundError:
         pass
     previous_exhook = sys.excepthook
     with notification_manager:
@@ -64,6 +64,7 @@ def test_notification_manager_no_gui(monkeypatch):
             'This is another information message'
         )
         assert len(notification_manager.records) == 2
+        assert len(store) == 2
         assert store[-1].type == 'info'
 
         # test that exceptions that go through sys.excepthook are catalogued
@@ -73,8 +74,12 @@ def test_notification_manager_no_gui(monkeypatch):
 
         # pytest intercepts the error, so we can manually call sys.excepthook
         assert sys.excepthook == notification_manager.receive_error
-        sys.excepthook(*sys.exc_info())
+        try:
+            raise ValueError("a")
+        except ValueError:
+            sys.excepthook(*sys.exc_info())
         assert len(notification_manager.records) == 3
+        assert len(store) == 3
         assert store[-1].type == 'error'
 
         # test that warnings that go through showwarning are catalogued
@@ -84,6 +89,14 @@ def test_notification_manager_no_gui(monkeypatch):
         assert len(notification_manager.records) == 4
         assert store[-1].type == 'warning'
 
+        show_error('This is an error')
+        assert len(notification_manager.records) == 5
+        assert store[-1].type == 'error'
+
+        show_warning('This is a warning')
+        assert len(notification_manager.records) == 6
+        assert store[-1].type == 'warning'
+
     # make sure we've restored the except hook
     assert sys.excepthook == previous_exhook
 
@@ -107,8 +120,7 @@ def test_notification_manager_no_gui_with_threading():
         with pytest.raises(PurposefulException):
             raise PurposefulException("this is an exception")
 
-    if PY38_OR_HIGHER:
-        previous_threading_exhook = threading.excepthook
+    previous_threading_exhook = threading.excepthook
 
     with notification_manager:
         notification_manager.records.clear()
@@ -117,21 +129,18 @@ def test_notification_manager_no_gui_with_threading():
         notification_manager.notification_ready.connect(store.append)
 
         # Test exception inside threads
-        if PY38_OR_HIGHER:
-            # `threading.excepthook` available only for Python >= 3.8
-            assert (
-                threading.excepthook
-                == notification_manager.receive_thread_error
-            )
+        assert (
+            threading.excepthook == notification_manager.receive_thread_error
+        )
 
         exception_thread = threading.Thread(target=_raise)
         exception_thread.start()
         time.sleep(0.02)
 
-        if PY38_OR_HIGHER:
+        try:
+            raise ValueError("a")
+        except ValueError:
             threading.excepthook(sys.exc_info())
-        else:
-            sys.excepthook(*sys.exc_info())
 
         assert len(notification_manager.records) == 1
         assert store[-1].type == 'error'
@@ -152,7 +161,6 @@ def test_notification_manager_no_gui_with_threading():
             raise AssertionError("Thread notification not received in time")
 
     # make sure we've restored the threading except hook
-    if PY38_OR_HIGHER:
-        assert threading.excepthook == previous_threading_exhook
+    assert threading.excepthook == previous_threading_exhook
 
     assert all(isinstance(x, Notification) for x in store)
