@@ -49,9 +49,11 @@ For more information see http://github.com/vispy/vispy/wiki/API_Events
 
 """
 import inspect
+import os
 import warnings
 import weakref
-from collections import Counter
+from collections.abc import Sequence
+from functools import partial
 from typing import (
     Any,
     Callable,
@@ -104,6 +106,7 @@ class Event:
         # Store args
         self._type = type
         self._native = native
+        self._kwargs = kwargs
         for k, v in kwargs.items():
             setattr(self, k, v)
 
@@ -201,8 +204,35 @@ class Event:
 _event_repr_depth = 0
 
 
-Callback = Callable[[Event], None]
+Callback = Union[Callable[[Event], None], Callable[[], None]]
 CallbackRef = Tuple['weakref.ReferenceType[Any]', str]  # dereferenced method
+CallbackStr = Tuple[
+    Union['weakref.ReferenceType[Any]', object], str
+]  # dereferenced method
+
+
+class _WeakCounter:
+    """
+    Similar to collection counter but has weak keys.
+
+    It will only implement the methods we use here.
+    """
+
+    def __init__(self):
+        self._counter = weakref.WeakKeyDictionary()
+        self._nonecount = 0
+
+    def update(self, iterable):
+        for it in iterable:
+            if it is None:
+                self._nonecount += 1
+            else:
+                self._counter[it] = self.get(it, 0) + 1
+
+    def get(self, key, default):
+        if key is None:
+            return self._nonecount
+        return self._counter.get(key, default)
 
 
 class EventEmitter:
@@ -253,10 +283,11 @@ class EventEmitter:
         self._callbacks: List[Union[Callback, CallbackRef]] = []
         # used when connecting new callbacks at specific positions
         self._callback_refs: List[Optional[str]] = []
+        self._callback_pass_event: List[bool] = []
 
         # count number of times this emitter is blocked for each callback.
         self._blocked: Dict[Optional[Callback], int] = {None: 0}
-        self._block_counter: Counter[Optional[Callback]] = Counter()
+        self._block_counter: _WeakCounter[Optional[Callback]] = _WeakCounter()
 
         # used to detect emitter loops
         self._emitting = False
@@ -336,18 +367,44 @@ class EventEmitter:
 
     @source.setter
     def source(self, s):
-        if s is None:
-            self._source = None
-        else:
-            self._source = weakref.ref(s)
+        self._source = None if s is None else weakref.ref(s)
+
+    def _is_core_callback(
+        self, callback: Union[CallbackRef, Callback], core: str
+    ):
+        """
+        Check if the callback is a core callback
+
+        Parameters
+        ----------
+        callback : Union[CallbackRef, Callback]
+            The callback to check. Callback could be function or
+            weak reference to object method coded using weakreference
+            to object and method name stored in tuple.
+        core : str
+            Name of core module, for example 'napari'.
+        """
+        try:
+            if isinstance(callback, partial):
+                callback = callback.func
+            if not isinstance(callback, tuple):
+                return callback.__module__.startswith(core + '.')
+            obj = callback[0]()  # get object behind weakref
+            if obj is None:  # object is dead
+                return False
+            return obj.__module__.startswith(core + '.')
+
+        except AttributeError:
+            return False
 
     def connect(
         self,
-        callback: Union[Callback, CallbackRef, 'EmitterGroup'],
+        callback: Union[Callback, CallbackRef, CallbackStr, 'EventEmitter'],
         ref: Union[bool, str] = False,
         position: Union[Literal['first'], Literal['last']] = 'first',
         before: Union[str, Callback, List[Union[str, Callback]], None] = None,
         after: Union[str, Callback, List[Union[str, Callback]], None] = None,
+        until: Optional['EventEmitter'] = None,
     ):
         """Connect this emitter to a new callback.
 
@@ -374,6 +431,9 @@ class EventEmitter:
         after : str | callback | list of str or callback | None
             List of callbacks that the current callback should follow.
             Can be None if no after-criteria should be used.
+        until : optional eventEmitter
+            if provided, when the event `until` is emitted, `callback`
+            will be disconnected from this emitter.
 
         Notes
         -----
@@ -399,7 +459,9 @@ class EventEmitter:
         callbacks = self.callbacks
         callback_refs = self.callback_refs
 
-        callback = self._normalize_cb(callback)
+        old_callback = callback
+
+        callback, pass_event = self._normalize_cb(callback)
 
         if callback in callbacks:
             return
@@ -439,21 +501,33 @@ class EventEmitter:
                     position=position,
                 )
             )
+        core_callbacks_indexes = [
+            i
+            for i, c in enumerate(self._callbacks)
+            if self._is_core_callback(c, 'napari')
+        ]
+        core_callbacks_count = (
+            max(core_callbacks_indexes) + 1 if core_callbacks_indexes else 0
+        )
+        if self._is_core_callback(callback, 'napari'):
+            callback_bounds = (0, core_callbacks_count)
+        else:
+            callback_bounds = (core_callbacks_count, len(callback_refs))
 
         # bounds: upper & lower bnds (inclusive) of possible cb locs
-        bounds: List[int] = list()
+        bounds: List[int] = []
         for ri, criteria in enumerate((before, after)):
             if criteria is None or criteria == []:
-                bounds.append(len(callback_refs) if ri == 0 else 0)
+                bounds.append(
+                    callback_bounds[1] if ri == 0 else callback_bounds[0]
+                )
             else:
                 if not isinstance(criteria, list):
                     criteria = [criteria]
                 for c in criteria:
                     count = sum(
-                        [
-                            (c == cn or c == cc)
-                            for cn, cc in zip(callback_refs, callbacks)
-                        ]
+                        c in [cn, cc]
+                        for cn, cc in zip(callback_refs, callbacks)
                     )
                     if count != 1:
                         raise ValueError(
@@ -489,9 +563,16 @@ class EventEmitter:
         # actually add the callback
         self._callbacks.insert(idx, callback)
         self._callback_refs.insert(idx, _ref)
-        return callback  # allows connect to be used as a decorator
+        self._callback_pass_event.insert(idx, pass_event)
 
-    def disconnect(self, callback: Union[Callback, CallbackRef, None] = None):
+        if until is not None:
+            until.connect(partial(self.disconnect, callback))
+
+        return old_callback  # allows connect to be used as a decorator
+
+    def disconnect(
+        self, callback: Union[Callback, CallbackRef, None, object] = None
+    ):
         """Disconnect a callback from this emitter.
 
         If no callback is specified, then *all* callbacks are removed.
@@ -500,42 +581,109 @@ class EventEmitter:
         if callback is None:
             self._callbacks = []
             self._callback_refs = []
-        else:
-            callback = self._normalize_cb(callback)
+            self._callback_pass_event = []
+        elif isinstance(callback, (Callable, tuple)):
+            callback, _pass_event = self._normalize_cb(callback)
             if callback in self._callbacks:
                 idx = self._callbacks.index(callback)
                 self._callbacks.pop(idx)
                 self._callback_refs.pop(idx)
+                self._callback_pass_event.pop(idx)
+        else:
+            index_list = []
+            for idx, local_callback in enumerate(self._callbacks):
+                if not (
+                    isinstance(local_callback, Sequence)
+                    and isinstance(local_callback[0], weakref.ref)
+                ):
+                    continue
+                if (
+                    local_callback[0]() is callback
+                    or local_callback[0]() is None
+                ):
+                    index_list.append(idx)
+            for idx in index_list[::-1]:
+                self._callbacks.pop(idx)
+                self._callback_refs.pop(idx)
+                self._callback_pass_event.pop(idx)
 
-    def _normalize_cb(self, callback) -> Union[CallbackRef, Callback]:
+    @staticmethod
+    def _get_proper_name(callback):
+        assert inspect.ismethod(callback)
+        obj = callback.__self__
+        if (
+            not hasattr(obj, callback.__name__)
+            or getattr(obj, callback.__name__) != callback
+        ):
+            # some decorators will alter method.__name__, so that obj.method
+            # will not be equal to getattr(obj, obj.method.__name__). We check
+            # for that case here and traverse to find the right method here.
+            for name in dir(obj):
+                meth = getattr(obj, name)
+                if inspect.ismethod(meth) and meth == callback:
+                    return obj, name
+            raise RuntimeError(
+                trans._(
+                    "During bind method {callback} of object {obj} an error happen",
+                    deferred=True,
+                    callback=callback,
+                    obj=obj,
+                )
+            )
+        return obj, callback.__name__
+
+    @staticmethod
+    def _check_signature(fun: Callable) -> bool:
+        """
+        Check if function will accept event parameter
+        """
+        signature = inspect.signature(fun)
+        parameters_list = list(signature.parameters.values())
+
+        if sum(map(_is_pos_arg, parameters_list)) > 1:
+            raise RuntimeError(
+                trans._(
+                    "Binning function cannot have more than one positional argument",
+                    deferred=True,
+                )
+            )
+
+        return any(
+            map(
+                lambda x: x.kind
+                in [
+                    inspect.Parameter.POSITIONAL_ONLY,
+                    inspect.Parameter.POSITIONAL_OR_KEYWORD,
+                    inspect.Parameter.VAR_POSITIONAL,
+                ],
+                signature.parameters.values(),
+            )
+        )
+
+    def _normalize_cb(
+        self, callback
+    ) -> Tuple[Union[CallbackRef, Callback], bool]:
         # dereference methods into a (self, method_name) pair so that we can
         # make the connection without making a strong reference to the
         # instance.
+        start_callback = callback
         if inspect.ismethod(callback):
-            old_callback = callback
-            callback = (callback.__self__, callback.__name__)
-            if (
-                not hasattr(callback[0], callback[1])
-                or getattr(callback[0], callback[1]) != old_callback
-            ):
-                # some decorators will alter method.__name__, so that obj.method
-                # will not be equal to getattr(obj, obj.method.__name__). We check
-                # for that case here and traverse to find the right method here.
-                for name in dir(callback[0]):
-                    meth = getattr(callback[0], name)
-                    if inspect.ismethod(meth) and meth == old_callback:
-                        callback = callback[0], name
-                        break
-                else:
-                    raise RuntimeError(
-                        f"During bind method {callback[1]} of object {callback[0]} an error happen"
-                    )
-
+            callback = self._get_proper_name(callback)
         # always use a weak ref
         if isinstance(callback, tuple) and not isinstance(
             callback[0], weakref.ref
         ):
-            callback = (weakref.ref(callback[0]),) + callback[1:]
+            callback = (weakref.ref(callback[0]), *callback[1:])
+
+        if isinstance(start_callback, Callable):
+            callback = callback, self._check_signature(start_callback)
+        else:
+            obj = callback[0]()
+            if obj is None:
+                callback = callback, False
+            else:
+                callback_fun = getattr(obj, callback[1])
+                callback = callback, self._check_signature(callback_fun)
 
         return callback
 
@@ -574,8 +722,12 @@ class EventEmitter:
                 self._block_counter.update([None])
                 return event
 
+            _log_event_stack(event)
+
             rem: List[CallbackRef] = []
-            for cb in self._callbacks[:]:
+            for cb, pass_event in zip(
+                self._callbacks[:], self._callback_pass_event[:]
+            ):
                 if isinstance(cb, tuple):
                     obj = cb[0]()
                     if obj is None:
@@ -585,7 +737,13 @@ class EventEmitter:
                     cb = getattr(obj, cb[1], None)
                     if cb is None:
                         warnings.warn(
-                            f"Problem with function {old_cb[1]} of {obj} connected to event {self}",
+                            trans._(
+                                "Problem with function {old_cb} of {obj} connected to event {self_}",
+                                deferred=True,
+                                old_cb=old_cb[1],
+                                obj=obj,
+                                self_=self,
+                            ),
                             stacklevel=2,
                             category=RuntimeWarning,
                         )
@@ -596,7 +754,7 @@ class EventEmitter:
                     self._block_counter.update([cb])
                     continue
 
-                self._invoke_callback(cb, event)
+                self._invoke_callback(cb, event if pass_event else None)
                 if event.blocked:
                     break
 
@@ -615,9 +773,14 @@ class EventEmitter:
 
         return event
 
-    def _invoke_callback(self, cb: Callback, event: Event):
+    def _invoke_callback(
+        self, cb: Union[Callback, Callable[[], None]], event: Optional[Event]
+    ):
         try:
-            cb(event)
+            if event is not None:
+                cb(event)
+            else:
+                cb()
         except Exception as e:
             # dead Qt object with living python pointer. not importing Qt
             # here... but this error is consistent across backends
@@ -779,12 +942,12 @@ class EmitterGroup(EventEmitter):
     source : object
         The object that the generated events apply to.
     auto_connect : bool
-        If *auto_connect* is True (default), then one connection will
+        If *auto_connect* is True, then one connection will
         be made for each emitter that looks like
         :func:`emitter.connect((source, 'on_' + event_name))
         <vispy.event.EventEmitter.connect>`.
         This provides a simple mechanism for automatically connecting a large
-        group of emitters to default callbacks.
+        group of emitters to default callbacks.  By default, false.
     emitters : keyword arguments
         See the :func:`add <vispy.event.EmitterGroup.add>` method.
     """
@@ -792,7 +955,7 @@ class EmitterGroup(EventEmitter):
     def __init__(
         self,
         source: Any = None,
-        auto_connect: bool = True,
+        auto_connect: bool = False,
         **emitters: Union[Type[Event], EventEmitter, None],
     ):
         EventEmitter.__init__(self, source)
@@ -875,7 +1038,7 @@ class EmitterGroup(EventEmitter):
                     source=self.source, type=name, event_class=emitter  # type: ignore
                 )
             elif not isinstance(emitter, EventEmitter):
-                raise Exception(
+                raise RuntimeError(
                     trans._(
                         'Emitter must be specified as either an EventEmitter instance or Event subclass. (got {name}={emitter})',
                         deferred=True,
@@ -1033,3 +1196,48 @@ class EventBlockerAll:
 
     def __exit__(self, *args):
         self.target.unblock_all()
+
+
+def _is_pos_arg(param: inspect.Parameter):
+    """
+    Check if param is positional or named and has no default parameter.
+    """
+    return (
+        param.kind
+        in [
+            inspect.Parameter.POSITIONAL_ONLY,
+            inspect.Parameter.POSITIONAL_OR_KEYWORD,
+        ]
+        and param.default == inspect.Parameter.empty
+    )
+
+
+try:
+    # this could move somewhere higher up in napari imports ... but where?
+    __import__('dotenv').load_dotenv()
+except ImportError:
+    pass
+
+
+def _noop(*a, **k):
+    pass
+
+
+_log_event_stack = _noop
+
+
+def set_event_tracing_enabled(enabled=True, cfg=None):
+    global _log_event_stack
+    if enabled:
+        from .debugging import log_event_stack
+
+        if cfg is not None:
+            _log_event_stack = partial(log_event_stack, cfg=cfg)
+        else:
+            _log_event_stack = log_event_stack
+    else:
+        _log_event_stack = _noop
+
+
+if os.getenv("NAPARI_DEBUG_EVENTS", '').lower() in ('1', 'true'):
+    set_event_tracing_enabled(True)
