@@ -8,6 +8,7 @@ import itertools
 import os
 import re
 import sys
+import warnings
 from enum import Enum, EnumMeta
 from os import fspath
 from os import path as os_path
@@ -17,6 +18,7 @@ from typing import (
     Any,
     Callable,
     Iterable,
+    Iterator,
     Optional,
     Type,
     TypeVar,
@@ -458,6 +460,19 @@ def ensure_list_of_layer_data_tuple(val):
     )
 
 
+def _quiet_array_equal(*a, **k):
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", "elementwise comparison")
+        return np.array_equal(*a, **k)
+
+
+def _arraylike_short_names(obj) -> Iterator[str]:
+    """Yield all the short names of an array-like or its class."""
+    type_ = type(obj) if not inspect.isclass(obj) else obj
+    for base in type_.mro():
+        yield f'{base.__module__.split(".", maxsplit=1)[0]}.{base.__name__}'
+
+
 def pick_equality_operator(obj) -> Callable[[Any, Any], bool]:
     """Return a function that can check equality between ``obj`` and another.
 
@@ -481,26 +496,44 @@ def pick_equality_operator(obj) -> Callable[[Any, Any], bool]:
     """
     import operator
 
-    type_ = type(obj) if not inspect.isclass(obj) else obj
-
     # yes, it's a little riskier, but we are checking namespaces instead of
     # actual `issubclass` here to avoid slow import times
     _known_arrays = {
-        'numpy.ndarray': np.array_equal,  # numpy.ndarray
+        'numpy.ndarray': _quiet_array_equal,  # numpy.ndarray
         'dask.Array': operator.is_,  # dask.array.core.Array
         'dask.Delayed': operator.is_,  # dask.delayed.Delayed
         'zarr.Array': operator.is_,  # zarr.core.Array
-        'xarray.DataArray': np.array_equal,  # xarray.core.dataarray.DataArray
+        'xarray.DataArray': _quiet_array_equal,  # xarray.core.dataarray.DataArray
     }
-    for base in type_.mro():
-        key = f'{base.__module__.split(".", maxsplit=1)[0]}.{base.__name__}'
-        func = _known_arrays.get(key)
+
+    for name in _arraylike_short_names(obj):
+        func = _known_arrays.get(name)
         if func:
             return func
 
     return operator.eq
 
 
+def _is_array_type(array, type_name: str) -> bool:
+    """Checks if an array-like instance or class is of the type described by a short name.
+
+    This is useful when you want to check the type of array-like quickly without
+    importing its package, which might take a long time.
+
+    Parameters
+    ----------
+    array
+        The array-like object.
+    type_name : str
+        The short name of the type to test against (e.g. 'numpy.ndarray', 'xarray.DataArray').
+
+    Returns
+    -------
+    True if the array is associated with the type name.
+    """
+    return type_name in _arraylike_short_names(array)
+
+
 def dir_hash(
     path: Union[str, Path], include_paths=True, ignore_hidden=True
 ) -> str:
