@@ -12,6 +12,17 @@ from typing import Callable, List, Optional, Sequence, Tuple, Type, Union
 from .events import Event, EventEmitter
 from .misc import StringEnum
 
+try:
+    from napari_error_reporter import capture_exception, install_error_reporter
+except ImportError:
+
+    def _noop(*_, **__):
+        pass
+
+    install_error_reporter = _noop
+    capture_exception = _noop
+
+
 name2num = {
     'error': 40,
     'warning': 30,
@@ -20,6 +31,17 @@ name2num = {
     'none': 0,
 }
 
+__all__ = [
+    'NotificationSeverity',
+    'Notification',
+    'ErrorNotification',
+    'WarningNotification',
+    'NotificationManager',
+    'show_info',
+    'show_error',
+    'show_console_notification',
+]
+
 
 class NotificationSeverity(StringEnum):
     """Severity levels for the notification dialog.  Along with icons for each."""
@@ -116,6 +138,10 @@ class Notification(Event):
 
 
 class ErrorNotification(Notification):
+    """
+    Notification at an Error severity level.
+    """
+
     exception: BaseException
 
     def __init__(self, exception: BaseException, *args, **kwargs):
@@ -135,6 +161,17 @@ class ErrorNotification(Notification):
         )
         return fmt(exc_info, as_html=True)
 
+    def as_text(self):
+        from ._tracebacks import get_tb_formatter
+
+        fmt = get_tb_formatter()
+        exc_info = (
+            self.exception.__class__,
+            self.exception,
+            self.exception.__traceback__,
+        )
+        return fmt(exc_info, as_html=False, color="NoColor")
+
     def __str__(self):
         from ._tracebacks import get_tb_formatter
 
@@ -148,6 +185,10 @@ class ErrorNotification(Notification):
 
 
 class WarningNotification(Notification):
+    """
+    Notification at a Warning severity level.
+    """
+
     warning: Warning
 
     def __init__(
@@ -224,6 +265,7 @@ class NotificationManager:
             # Patch for Python < 3.8
             _setup_thread_excepthook()
 
+        install_error_reporter()
         self._originals_except_hooks.append(sys.excepthook)
         self._original_showwarnings_hooks.append(warnings.showwarning)
 
@@ -257,12 +299,16 @@ class NotificationManager:
     ):
         if isinstance(value, KeyboardInterrupt):
             sys.exit("Closed by KeyboardInterrupt")
+
+        capture_exception(value)
+
         if self.exit_on_error:
             sys.__excepthook__(exctype, value, traceback)
             sys.exit("Exit on error")
         if not self.catch_error:
             sys.__excepthook__(exctype, value, traceback)
             return
+
         try:
             self.dispatch(Notification.from_exception(value))
         except Exception:
@@ -291,10 +337,36 @@ notification_manager = NotificationManager()
 
 
 def show_info(message: str):
-    notification_manager.receive_info(message)
+    """
+    Show an info message in the notification manager.
+    """
+    notification_manager.dispatch(
+        Notification(message, severity=NotificationSeverity.INFO)
+    )
+
+
+def show_warning(message: str):
+    """
+    Show a warning in the notification manager.
+    """
+    notification_manager.dispatch(
+        Notification(message, severity=NotificationSeverity.WARNING)
+    )
+
+
+def show_error(message: str):
+    """
+    Show an error in the notification manager.
+    """
+    notification_manager.dispatch(
+        Notification(message, severity=NotificationSeverity.ERROR)
+    )
 
 
 def show_console_notification(notification: Notification):
+    """
+    Show a notification in the console.
+    """
     try:
         from ..settings import get_settings
 
