@@ -1,6 +1,5 @@
 # syntax_style for the console must be one of the supported styles from
 # pygments - see here for examples https://help.farbox.com/pygments.html
-import contextlib
 import re
 import warnings
 from ast import literal_eval
@@ -71,9 +70,10 @@ class Theme(EventedModel):
     def _ensure_syntax_style(value: str) -> str:
         from pygments.styles import STYLE_MAP
 
-        assert value in STYLE_MAP, (
-            "Incorrect `syntax_style` value provided. Please use one of the following:"
-            f" {', '.join(STYLE_MAP)}"
+        assert value in STYLE_MAP, trans._(
+            "Incorrect `syntax_style` value provided. Please use one of the following: {syntax_style}",
+            deferred=True,
+            syntax_style=f" {', '.join(STYLE_MAP)}",
         )
         return value
 
@@ -173,7 +173,7 @@ def get_system_theme():
     return name
 
 
-def get_theme(name, as_dict=True):
+def get_theme(name, as_dict=None):
     """Get a copy of theme based on it's name.
 
     If you get a copy of the theme, changes to the theme model will not be
@@ -198,26 +198,7 @@ def get_theme(name, as_dict=True):
     if name == "system":
         name = get_system_theme()
 
-    if name in _themes:
-        theme = _themes[name]
-        _theme = theme.copy()
-        if as_dict:
-            warnings.warn(
-                trans._(
-                    "Themes were changed to use evented model with Pydantic's color type rather than the `rgb(x, y, z)`. You can get the old color by calling `color.as_rgb()`. The `as_dict=True` option will be removed in 0.X.X",
-                    deferred=True,
-                ),
-                category=FutureWarning,
-                stacklevel=2,
-            )
-            _theme = _theme.dict()
-            _theme = {
-                k: v if not isinstance(v, Color) else v.as_rgb()
-                for (k, v) in _theme.items()
-            }
-            return _theme
-        return _theme
-    else:
+    if name not in _themes:
         raise ValueError(
             trans._(
                 "Unrecognized theme {name}. Available themes are {themes}",
@@ -226,6 +207,26 @@ def get_theme(name, as_dict=True):
                 themes=available_themes(),
             )
         )
+    theme = _themes[name]
+    _theme = theme.copy()
+    if as_dict is None:
+        warnings.warn(
+            trans._(
+                "Themes were changed to use evented model with Pydantic's color type rather than the `rgb(x, y, z)`. The `as_dict=True` option will be changed to `as_dict=False` in 0.4.15",
+                deferred=True,
+            ),
+            category=FutureWarning,
+            stacklevel=2,
+        )
+        as_dict = True
+    if as_dict:
+        _theme = _theme.dict()
+        _theme = {
+            k: v if not isinstance(v, Color) else v.as_rgb()
+            for (k, v) in _theme.items()
+        }
+        return _theme
+    return _theme
 
 
 def register_theme(name, theme):
@@ -266,16 +267,11 @@ def available_themes():
     return tuple(_themes) + ("system",)
 
 
-def rebuild_theme_settings(event=None):
+def rebuild_theme_settings():
     """update theme information in settings.
 
     here we simply update the settings to reflect current list of available
     themes.
-
-    parameters
-    ----------
-    event : event
-        Unused event.
     """
     from ..settings import get_settings
 
@@ -283,7 +279,7 @@ def rebuild_theme_settings(event=None):
     settings.appearance.refresh_themes()
 
 
-_themes = EventedDict(
+_themes: EventedDict[str, Theme] = EventedDict(
     {
         'dark': Theme(
             **{
@@ -298,7 +294,7 @@ _themes = EventedDict(
                 'warning': 'rgb(153, 18, 31)',
                 'current': 'rgb(0, 122, 204)',
                 'syntax_style': 'native',
-                'console': 'rgb(0, 0, 0)',
+                'console': 'rgb(18, 18, 18)',
                 'canvas': 'black',
             }
         ),
@@ -323,15 +319,19 @@ _themes = EventedDict(
     basetype=Theme,
 )
 
-with contextlib.suppress(ImportError):
-    from npe2 import plugin_manager
 
-    for theme in plugin_manager._themes.values():
+# this function here instead of plugins._npe2 to avoid circular import
+def _install_npe2_themes(_themes):
+    import npe2
+
+    for theme in npe2.PluginManager.instance().iter_themes():
         # `theme.type` is dark/light and supplies defaults for keys that
         # are not provided by the plugin
         d = _themes[theme.type].dict()
         d.update(theme.colors.dict(exclude_unset=True))
         _themes[theme.id] = Theme(**d)
 
+
+_install_npe2_themes(_themes)
 _themes.events.added.connect(rebuild_theme_settings)
 _themes.events.removed.connect(rebuild_theme_settings)
